/* conversation_details.c generated by valac 0.56.19, the Vala compiler
 * generated from conversation_details.vala, do not modify */

#include <glib-object.h>
#include "libdino.h"
#include <glib.h>
#include "xmpp-vala.h"
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gee.h>
#include <adwaita.h>
#include "dino_i18n.h"
#include <float.h>
#include <math.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define DINO_UI_MODEL_TYPE_CONVERSATION_DETAILS (dino_ui_model_conversation_details_get_type ())
#define DINO_UI_MODEL_CONVERSATION_DETAILS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_UI_MODEL_TYPE_CONVERSATION_DETAILS, DinoUiModelConversationDetails))
#define DINO_UI_MODEL_CONVERSATION_DETAILS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_UI_MODEL_TYPE_CONVERSATION_DETAILS, DinoUiModelConversationDetailsClass))
#define DINO_UI_MODEL_IS_CONVERSATION_DETAILS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_UI_MODEL_TYPE_CONVERSATION_DETAILS))
#define DINO_UI_MODEL_IS_CONVERSATION_DETAILS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_UI_MODEL_TYPE_CONVERSATION_DETAILS))
#define DINO_UI_MODEL_CONVERSATION_DETAILS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_UI_MODEL_TYPE_CONVERSATION_DETAILS, DinoUiModelConversationDetailsClass))

typedef struct _DinoUiModelConversationDetails DinoUiModelConversationDetails;
typedef struct _DinoUiModelConversationDetailsClass DinoUiModelConversationDetailsClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block45Data Block45Data;
#define _xmpp_jid_unref0(var) ((var == NULL) ? NULL : (var = (xmpp_jid_unref (var), NULL)))
#define _xmpp_xep_data_forms_data_form_unref0(var) ((var == NULL) ? NULL : (var = (xmpp_xep_data_forms_data_form_unref (var), NULL)))
typedef struct _DinoUiModelConversationDetailsPrivate DinoUiModelConversationDetailsPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))

#define DINO_UI_VIEW_MODEL_TYPE_CONVERSATION_DETAILS (dino_ui_view_model_conversation_details_get_type ())
#define DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_UI_VIEW_MODEL_TYPE_CONVERSATION_DETAILS, DinoUiViewModelConversationDetails))
#define DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_UI_VIEW_MODEL_TYPE_CONVERSATION_DETAILS, DinoUiViewModelConversationDetailsClass))
#define DINO_UI_VIEW_MODEL_IS_CONVERSATION_DETAILS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_UI_VIEW_MODEL_TYPE_CONVERSATION_DETAILS))
#define DINO_UI_VIEW_MODEL_IS_CONVERSATION_DETAILS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_UI_VIEW_MODEL_TYPE_CONVERSATION_DETAILS))
#define DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_UI_VIEW_MODEL_TYPE_CONVERSATION_DETAILS, DinoUiViewModelConversationDetailsClass))

typedef struct _DinoUiViewModelConversationDetails DinoUiViewModelConversationDetails;
typedef struct _DinoUiViewModelConversationDetailsClass DinoUiViewModelConversationDetailsClass;
typedef struct _Block46Data Block46Data;

#define DINO_UI_VIEW_MODEL_TYPE_AVATAR_PICTURE_MODEL (dino_ui_view_model_avatar_picture_model_get_type ())
#define DINO_UI_VIEW_MODEL_AVATAR_PICTURE_MODEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_UI_VIEW_MODEL_TYPE_AVATAR_PICTURE_MODEL, DinoUiViewModelAvatarPictureModel))
#define DINO_UI_VIEW_MODEL_AVATAR_PICTURE_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_UI_VIEW_MODEL_TYPE_AVATAR_PICTURE_MODEL, DinoUiViewModelAvatarPictureModelClass))
#define DINO_UI_VIEW_MODEL_IS_AVATAR_PICTURE_MODEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_UI_VIEW_MODEL_TYPE_AVATAR_PICTURE_MODEL))
#define DINO_UI_VIEW_MODEL_IS_AVATAR_PICTURE_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_UI_VIEW_MODEL_TYPE_AVATAR_PICTURE_MODEL))
#define DINO_UI_VIEW_MODEL_AVATAR_PICTURE_MODEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_UI_VIEW_MODEL_TYPE_AVATAR_PICTURE_MODEL, DinoUiViewModelAvatarPictureModelClass))

typedef struct _DinoUiViewModelAvatarPictureModel DinoUiViewModelAvatarPictureModel;
typedef struct _DinoUiViewModelAvatarPictureModelClass DinoUiViewModelAvatarPictureModelClass;

#define DINO_UI_VIEW_MODEL_TYPE_COMPAT_AVATAR_PICTURE_MODEL (dino_ui_view_model_compat_avatar_picture_model_get_type ())
#define DINO_UI_VIEW_MODEL_COMPAT_AVATAR_PICTURE_MODEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_UI_VIEW_MODEL_TYPE_COMPAT_AVATAR_PICTURE_MODEL, DinoUiViewModelCompatAvatarPictureModel))
#define DINO_UI_VIEW_MODEL_COMPAT_AVATAR_PICTURE_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_UI_VIEW_MODEL_TYPE_COMPAT_AVATAR_PICTURE_MODEL, DinoUiViewModelCompatAvatarPictureModelClass))
#define DINO_UI_VIEW_MODEL_IS_COMPAT_AVATAR_PICTURE_MODEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_UI_VIEW_MODEL_TYPE_COMPAT_AVATAR_PICTURE_MODEL))
#define DINO_UI_VIEW_MODEL_IS_COMPAT_AVATAR_PICTURE_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_UI_VIEW_MODEL_TYPE_COMPAT_AVATAR_PICTURE_MODEL))
#define DINO_UI_VIEW_MODEL_COMPAT_AVATAR_PICTURE_MODEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_UI_VIEW_MODEL_TYPE_COMPAT_AVATAR_PICTURE_MODEL, DinoUiViewModelCompatAvatarPictureModelClass))

typedef struct _DinoUiViewModelCompatAvatarPictureModel DinoUiViewModelCompatAvatarPictureModel;
typedef struct _DinoUiViewModelCompatAvatarPictureModelClass DinoUiViewModelCompatAvatarPictureModelClass;
typedef struct _DinoUiViewModelConversationDetailsPrivate DinoUiViewModelConversationDetailsPrivate;

#define DINO_UI_MODEL_TYPE_CONFERENCE_MEMBER (dino_ui_model_conference_member_get_type ())
#define DINO_UI_MODEL_CONFERENCE_MEMBER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_UI_MODEL_TYPE_CONFERENCE_MEMBER, DinoUiModelConferenceMember))
#define DINO_UI_MODEL_CONFERENCE_MEMBER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_UI_MODEL_TYPE_CONFERENCE_MEMBER, DinoUiModelConferenceMemberClass))
#define DINO_UI_MODEL_IS_CONFERENCE_MEMBER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_UI_MODEL_TYPE_CONFERENCE_MEMBER))
#define DINO_UI_MODEL_IS_CONFERENCE_MEMBER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_UI_MODEL_TYPE_CONFERENCE_MEMBER))
#define DINO_UI_MODEL_CONFERENCE_MEMBER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_UI_MODEL_TYPE_CONFERENCE_MEMBER, DinoUiModelConferenceMemberClass))

typedef struct _DinoUiModelConferenceMember DinoUiModelConferenceMember;
typedef struct _DinoUiModelConferenceMemberClass DinoUiModelConferenceMemberClass;

#define DINO_UI_VIEW_MODEL_TYPE_CONFERENCE_MEMBER_LIST_ROW (dino_ui_view_model_conference_member_list_row_get_type ())
#define DINO_UI_VIEW_MODEL_CONFERENCE_MEMBER_LIST_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_UI_VIEW_MODEL_TYPE_CONFERENCE_MEMBER_LIST_ROW, DinoUiViewModelConferenceMemberListRow))
#define DINO_UI_VIEW_MODEL_CONFERENCE_MEMBER_LIST_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_UI_VIEW_MODEL_TYPE_CONFERENCE_MEMBER_LIST_ROW, DinoUiViewModelConferenceMemberListRowClass))
#define DINO_UI_VIEW_MODEL_IS_CONFERENCE_MEMBER_LIST_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_UI_VIEW_MODEL_TYPE_CONFERENCE_MEMBER_LIST_ROW))
#define DINO_UI_VIEW_MODEL_IS_CONFERENCE_MEMBER_LIST_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_UI_VIEW_MODEL_TYPE_CONFERENCE_MEMBER_LIST_ROW))
#define DINO_UI_VIEW_MODEL_CONFERENCE_MEMBER_LIST_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_UI_VIEW_MODEL_TYPE_CONFERENCE_MEMBER_LIST_ROW, DinoUiViewModelConferenceMemberListRowClass))

typedef struct _DinoUiViewModelConferenceMemberListRow DinoUiViewModelConferenceMemberListRow;
typedef struct _DinoUiViewModelConferenceMemberListRowClass DinoUiViewModelConferenceMemberListRowClass;
typedef enum  {
	DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_BLOCK_STATE_USER,
	DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_BLOCK_STATE_DOMAIN,
	DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_BLOCK_STATE_UNBLOCK
} DinoUiViewModelConversationDetailsBlockState;

#define DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_TYPE_BLOCK_STATE (dino_ui_view_model_conversation_details_block_state_get_type ())
typedef enum  {
	DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_NOTIFICATION_SETTING_DEFAULT,
	DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_NOTIFICATION_SETTING_ON,
	DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_NOTIFICATION_SETTING_HIGHLIGHT,
	DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_NOTIFICATION_SETTING_OFF
} DinoUiViewModelConversationDetailsNotificationSetting;

#define DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_TYPE_NOTIFICATION_SETTING (dino_ui_view_model_conversation_details_notification_setting_get_type ())
typedef enum  {
	DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_NOTIFICATION_OPTIONS_ON_OFF,
	DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_NOTIFICATION_OPTIONS_ON_HIGHLIGHT_OFF
} DinoUiViewModelConversationDetailsNotificationOptions;

#define DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_TYPE_NOTIFICATION_OPTIONS (dino_ui_view_model_conversation_details_notification_options_get_type ())

#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_ANY (dino_ui_view_model_preferences_row_any_get_type ())
#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_ANY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_ANY, DinoUiViewModelPreferencesRowAny))
#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_ANY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_ANY, DinoUiViewModelPreferencesRowAnyClass))
#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_IS_ANY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_ANY))
#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_IS_ANY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_ANY))
#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_ANY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_ANY, DinoUiViewModelPreferencesRowAnyClass))

typedef struct _DinoUiViewModelPreferencesRowAny DinoUiViewModelPreferencesRowAny;
typedef struct _DinoUiViewModelPreferencesRowAnyClass DinoUiViewModelPreferencesRowAnyClass;

#define DINO_UI_CONVERSATION_DETAILS_TYPE_DIALOG (dino_ui_conversation_details_dialog_get_type ())
#define DINO_UI_CONVERSATION_DETAILS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_UI_CONVERSATION_DETAILS_TYPE_DIALOG, DinoUiConversationDetailsDialog))
#define DINO_UI_CONVERSATION_DETAILS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_UI_CONVERSATION_DETAILS_TYPE_DIALOG, DinoUiConversationDetailsDialogClass))
#define DINO_UI_CONVERSATION_DETAILS_IS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_UI_CONVERSATION_DETAILS_TYPE_DIALOG))
#define DINO_UI_CONVERSATION_DETAILS_IS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_UI_CONVERSATION_DETAILS_TYPE_DIALOG))
#define DINO_UI_CONVERSATION_DETAILS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_UI_CONVERSATION_DETAILS_TYPE_DIALOG, DinoUiConversationDetailsDialogClass))

typedef struct _DinoUiConversationDetailsDialog DinoUiConversationDetailsDialog;
typedef struct _DinoUiConversationDetailsDialogClass DinoUiConversationDetailsDialogClass;
typedef struct _Block47Data Block47Data;

#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_TEXT (dino_ui_view_model_preferences_row_text_get_type ())
#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_TEXT, DinoUiViewModelPreferencesRowText))
#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TEXT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_TEXT, DinoUiViewModelPreferencesRowTextClass))
#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_IS_TEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_TEXT))
#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_IS_TEXT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_TEXT))
#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TEXT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_TEXT, DinoUiViewModelPreferencesRowTextClass))

typedef struct _DinoUiViewModelPreferencesRowText DinoUiViewModelPreferencesRowText;
typedef struct _DinoUiViewModelPreferencesRowTextClass DinoUiViewModelPreferencesRowTextClass;

#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_ENTRY (dino_ui_view_model_preferences_row_entry_get_type ())
#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_ENTRY, DinoUiViewModelPreferencesRowEntry))
#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_ENTRY, DinoUiViewModelPreferencesRowEntryClass))
#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_IS_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_ENTRY))
#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_IS_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_ENTRY))
#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_ENTRY, DinoUiViewModelPreferencesRowEntryClass))

typedef struct _DinoUiViewModelPreferencesRowEntry DinoUiViewModelPreferencesRowEntry;
typedef struct _DinoUiViewModelPreferencesRowEntryClass DinoUiViewModelPreferencesRowEntryClass;
typedef struct _Block48Data Block48Data;

#define DINO_UI_TYPE_APPLICATION (dino_ui_application_get_type ())
#define DINO_UI_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_UI_TYPE_APPLICATION, DinoUiApplication))
#define DINO_UI_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_UI_TYPE_APPLICATION, DinoUiApplicationClass))
#define DINO_UI_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_UI_TYPE_APPLICATION))
#define DINO_UI_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_UI_TYPE_APPLICATION))
#define DINO_UI_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_UI_TYPE_APPLICATION, DinoUiApplicationClass))

typedef struct _DinoUiApplication DinoUiApplication;
typedef struct _DinoUiApplicationClass DinoUiApplicationClass;

#define DINO_UI_CONTACT_DETAILS_TYPE_SETTINGS_PROVIDER (dino_ui_contact_details_settings_provider_get_type ())
#define DINO_UI_CONTACT_DETAILS_SETTINGS_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_UI_CONTACT_DETAILS_TYPE_SETTINGS_PROVIDER, DinoUiContactDetailsSettingsProvider))
#define DINO_UI_CONTACT_DETAILS_SETTINGS_PROVIDER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_UI_CONTACT_DETAILS_TYPE_SETTINGS_PROVIDER, DinoUiContactDetailsSettingsProviderClass))
#define DINO_UI_CONTACT_DETAILS_IS_SETTINGS_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_UI_CONTACT_DETAILS_TYPE_SETTINGS_PROVIDER))
#define DINO_UI_CONTACT_DETAILS_IS_SETTINGS_PROVIDER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_UI_CONTACT_DETAILS_TYPE_SETTINGS_PROVIDER))
#define DINO_UI_CONTACT_DETAILS_SETTINGS_PROVIDER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_UI_CONTACT_DETAILS_TYPE_SETTINGS_PROVIDER, DinoUiContactDetailsSettingsProviderClass))

typedef struct _DinoUiContactDetailsSettingsProvider DinoUiContactDetailsSettingsProvider;
typedef struct _DinoUiContactDetailsSettingsProviderClass DinoUiContactDetailsSettingsProviderClass;

#define DINO_UI_CONTACT_DETAILS_TYPE_PERMISSIONS_PROVIDER (dino_ui_contact_details_permissions_provider_get_type ())
#define DINO_UI_CONTACT_DETAILS_PERMISSIONS_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_UI_CONTACT_DETAILS_TYPE_PERMISSIONS_PROVIDER, DinoUiContactDetailsPermissionsProvider))
#define DINO_UI_CONTACT_DETAILS_PERMISSIONS_PROVIDER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_UI_CONTACT_DETAILS_TYPE_PERMISSIONS_PROVIDER, DinoUiContactDetailsPermissionsProviderClass))
#define DINO_UI_CONTACT_DETAILS_IS_PERMISSIONS_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_UI_CONTACT_DETAILS_TYPE_PERMISSIONS_PROVIDER))
#define DINO_UI_CONTACT_DETAILS_IS_PERMISSIONS_PROVIDER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_UI_CONTACT_DETAILS_TYPE_PERMISSIONS_PROVIDER))
#define DINO_UI_CONTACT_DETAILS_PERMISSIONS_PROVIDER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_UI_CONTACT_DETAILS_TYPE_PERMISSIONS_PROVIDER, DinoUiContactDetailsPermissionsProviderClass))

typedef struct _DinoUiContactDetailsPermissionsProvider DinoUiContactDetailsPermissionsProvider;
typedef struct _DinoUiContactDetailsPermissionsProviderClass DinoUiContactDetailsPermissionsProviderClass;

#define DINO_UI_UTIL_TYPE_LABEL_HYBRID (dino_ui_util_label_hybrid_get_type ())
#define DINO_UI_UTIL_LABEL_HYBRID(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_UI_UTIL_TYPE_LABEL_HYBRID, DinoUiUtilLabelHybrid))
#define DINO_UI_UTIL_LABEL_HYBRID_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_UI_UTIL_TYPE_LABEL_HYBRID, DinoUiUtilLabelHybridClass))
#define DINO_UI_UTIL_IS_LABEL_HYBRID(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_UI_UTIL_TYPE_LABEL_HYBRID))
#define DINO_UI_UTIL_IS_LABEL_HYBRID_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_UI_UTIL_TYPE_LABEL_HYBRID))
#define DINO_UI_UTIL_LABEL_HYBRID_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_UI_UTIL_TYPE_LABEL_HYBRID, DinoUiUtilLabelHybridClass))

typedef struct _DinoUiUtilLabelHybrid DinoUiUtilLabelHybrid;
typedef struct _DinoUiUtilLabelHybridClass DinoUiUtilLabelHybridClass;

#define DINO_UI_UTIL_TYPE_ENTRY_LABEL_HYBRID (dino_ui_util_entry_label_hybrid_get_type ())
#define DINO_UI_UTIL_ENTRY_LABEL_HYBRID(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_UI_UTIL_TYPE_ENTRY_LABEL_HYBRID, DinoUiUtilEntryLabelHybrid))
#define DINO_UI_UTIL_ENTRY_LABEL_HYBRID_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_UI_UTIL_TYPE_ENTRY_LABEL_HYBRID, DinoUiUtilEntryLabelHybridClass))
#define DINO_UI_UTIL_IS_ENTRY_LABEL_HYBRID(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_UI_UTIL_TYPE_ENTRY_LABEL_HYBRID))
#define DINO_UI_UTIL_IS_ENTRY_LABEL_HYBRID_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_UI_UTIL_TYPE_ENTRY_LABEL_HYBRID))
#define DINO_UI_UTIL_ENTRY_LABEL_HYBRID_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_UI_UTIL_TYPE_ENTRY_LABEL_HYBRID, DinoUiUtilEntryLabelHybridClass))

typedef struct _DinoUiUtilEntryLabelHybrid DinoUiUtilEntryLabelHybrid;
typedef struct _DinoUiUtilEntryLabelHybridClass DinoUiUtilEntryLabelHybridClass;

#define DINO_UI_UTIL_TYPE_COMBO_BOX_TEXT_LABEL_HYBRID (dino_ui_util_combo_box_text_label_hybrid_get_type ())
#define DINO_UI_UTIL_COMBO_BOX_TEXT_LABEL_HYBRID(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_UI_UTIL_TYPE_COMBO_BOX_TEXT_LABEL_HYBRID, DinoUiUtilComboBoxTextLabelHybrid))
#define DINO_UI_UTIL_COMBO_BOX_TEXT_LABEL_HYBRID_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_UI_UTIL_TYPE_COMBO_BOX_TEXT_LABEL_HYBRID, DinoUiUtilComboBoxTextLabelHybridClass))
#define DINO_UI_UTIL_IS_COMBO_BOX_TEXT_LABEL_HYBRID(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_UI_UTIL_TYPE_COMBO_BOX_TEXT_LABEL_HYBRID))
#define DINO_UI_UTIL_IS_COMBO_BOX_TEXT_LABEL_HYBRID_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_UI_UTIL_TYPE_COMBO_BOX_TEXT_LABEL_HYBRID))
#define DINO_UI_UTIL_COMBO_BOX_TEXT_LABEL_HYBRID_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_UI_UTIL_TYPE_COMBO_BOX_TEXT_LABEL_HYBRID, DinoUiUtilComboBoxTextLabelHybridClass))

typedef struct _DinoUiUtilComboBoxTextLabelHybrid DinoUiUtilComboBoxTextLabelHybrid;
typedef struct _DinoUiUtilComboBoxTextLabelHybridClass DinoUiUtilComboBoxTextLabelHybridClass;

#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_WIDGET_DEPRECATED (dino_ui_view_model_preferences_row_widget_deprecated_get_type ())
#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_WIDGET_DEPRECATED(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_WIDGET_DEPRECATED, DinoUiViewModelPreferencesRowWidgetDeprecated))
#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_WIDGET_DEPRECATED_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_WIDGET_DEPRECATED, DinoUiViewModelPreferencesRowWidgetDeprecatedClass))
#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_IS_WIDGET_DEPRECATED(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_WIDGET_DEPRECATED))
#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_IS_WIDGET_DEPRECATED_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_WIDGET_DEPRECATED))
#define DINO_UI_VIEW_MODEL_PREFERENCES_ROW_WIDGET_DEPRECATED_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_WIDGET_DEPRECATED, DinoUiViewModelPreferencesRowWidgetDeprecatedClass))

typedef struct _DinoUiViewModelPreferencesRowWidgetDeprecated DinoUiViewModelPreferencesRowWidgetDeprecated;
typedef struct _DinoUiViewModelPreferencesRowWidgetDeprecatedClass DinoUiViewModelPreferencesRowWidgetDeprecatedClass;
typedef struct _DinoUiViewModelPreferencesRowAnyPrivate DinoUiViewModelPreferencesRowAnyPrivate;
typedef struct _DinoUiViewModelPreferencesRowWidgetDeprecatedPrivate DinoUiViewModelPreferencesRowWidgetDeprecatedPrivate;

struct _Block45Data {
	int _ref_count_;
	DinoUiModelConversationDetails* model;
	DinoStreamInteractor* stream_interactor;
};

struct _DinoUiModelConversationDetails {
	GObject parent_instance;
	DinoUiModelConversationDetailsPrivate * priv;
	gchar* data_form_bak;
	GListStore* members;
};

struct _DinoUiModelConversationDetailsClass {
	GObjectClass parent_class;
};

struct _Block46Data {
	int _ref_count_;
	DinoUiModelConversationDetails* model;
	DinoUiViewModelConversationDetails* view_model;
	DinoStreamInteractor* stream_interactor;
};

struct _DinoUiViewModelConversationDetails {
	GObject parent_instance;
	DinoUiViewModelConversationDetailsPrivate * priv;
	GListStore* about_rows;
	GListStore* settings_rows;
	GtkMapListModel* members;
	GtkSortListModel* members_sorted;
};

struct _DinoUiViewModelConversationDetailsClass {
	GObjectClass parent_class;
};

struct _Block47Data {
	int _ref_count_;
	DinoUiConversationDetailsDialog* dialog;
	DinoUiModelConversationDetails* model;
	DinoEntitiesConversation* conversation;
	DinoStreamInteractor* stream_interactor;
};

struct _Block48Data {
	int _ref_count_;
	Block47Data * _data47_;
	DinoUiViewModelPreferencesRowEntry* about_row;
};

struct _DinoUiViewModelPreferencesRowAny {
	GObject parent_instance;
	DinoUiViewModelPreferencesRowAnyPrivate * priv;
};

struct _DinoUiViewModelPreferencesRowAnyClass {
	GObjectClass parent_class;
};

struct _DinoUiViewModelPreferencesRowWidgetDeprecated {
	DinoUiViewModelPreferencesRowAny parent_instance;
	DinoUiViewModelPreferencesRowWidgetDeprecatedPrivate * priv;
	GtkWidget* widget;
};

struct _DinoUiViewModelPreferencesRowWidgetDeprecatedClass {
	DinoUiViewModelPreferencesRowAnyClass parent_class;
};

VALA_EXTERN GType dino_ui_model_conversation_details_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUiModelConversationDetails, g_object_unref)
VALA_EXTERN void dino_ui_conversation_details_populate_dialog (DinoUiModelConversationDetails* model,
                                                   DinoEntitiesConversation* conversation,
                                                   DinoStreamInteractor* stream_interactor);
static Block45Data* block45_data_ref (Block45Data* _data45_);
static void block45_data_unref (void * _userdata_);
VALA_EXTERN void dino_ui_model_conversation_details_set_conversation (DinoUiModelConversationDetails* self,
                                                          DinoEntitiesConversation* value);
VALA_EXTERN void dino_ui_model_conversation_details_set_display_name (DinoUiModelConversationDetails* self,
                                                          DinoModelConversationDisplayName* value);
VALA_EXTERN DinoEntitiesConversation* dino_ui_model_conversation_details_get_conversation (DinoUiModelConversationDetails* self);
VALA_EXTERN void dino_ui_model_conversation_details_set_blocked (DinoUiModelConversationDetails* self,
                                                     gboolean value);
VALA_EXTERN void dino_ui_model_conversation_details_set_domain_blocked (DinoUiModelConversationDetails* self,
                                                            gboolean value);
static void ___lambda176_ (Block45Data* _data45_,
                    GObject* _,
                    GAsyncResult* res);
VALA_EXTERN void dino_ui_model_conversation_details_set_data_form (DinoUiModelConversationDetails* self,
                                                       XmppXepDataFormsDataForm* value);
VALA_EXTERN XmppXepDataFormsDataForm* dino_ui_model_conversation_details_get_data_form (DinoUiModelConversationDetails* self);
static void ____lambda176__gasync_ready_callback (GObject* source_object,
                                           GAsyncResult* res,
                                           gpointer self);
VALA_EXTERN GType dino_ui_view_model_conversation_details_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUiViewModelConversationDetails, g_object_unref)
VALA_EXTERN void dino_ui_conversation_details_bind_dialog (DinoUiModelConversationDetails* model,
                                               DinoUiViewModelConversationDetails* view_model,
                                               DinoStreamInteractor* stream_interactor);
static Block46Data* block46_data_ref (Block46Data* _data46_);
static void block46_data_unref (void * _userdata_);
VALA_EXTERN DinoUiViewModelCompatAvatarPictureModel* dino_ui_view_model_compat_avatar_picture_model_new (DinoStreamInteractor* stream_interactor);
VALA_EXTERN DinoUiViewModelCompatAvatarPictureModel* dino_ui_view_model_compat_avatar_picture_model_construct (GType object_type,
                                                                                                   DinoStreamInteractor* stream_interactor);
VALA_EXTERN GType dino_ui_view_model_avatar_picture_model_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUiViewModelAvatarPictureModel, g_object_unref)
VALA_EXTERN GType dino_ui_view_model_compat_avatar_picture_model_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUiViewModelCompatAvatarPictureModel, g_object_unref)
VALA_EXTERN DinoUiViewModelCompatAvatarPictureModel* dino_ui_view_model_compat_avatar_picture_model_set_conversation (DinoUiViewModelCompatAvatarPictureModel* self,
                                                                                                          DinoEntitiesConversation* conversation);
VALA_EXTERN void dino_ui_view_model_conversation_details_set_avatar (DinoUiViewModelConversationDetails* self,
                                                         DinoUiViewModelCompatAvatarPictureModel* value);
VALA_EXTERN void dino_ui_view_model_conversation_details_set_show_blocked (DinoUiViewModelConversationDetails* self,
                                                               gboolean value);
static GObject* __lambda177_ (Block46Data* _data46_,
                       GObject* item);
VALA_EXTERN GType dino_ui_model_conference_member_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUiModelConferenceMember, g_object_unref)
VALA_EXTERN XmppJid* dino_ui_model_conference_member_get_jid (DinoUiModelConferenceMember* self);
VALA_EXTERN DinoUiViewModelCompatAvatarPictureModel* dino_ui_view_model_compat_avatar_picture_model_add_participant (DinoUiViewModelCompatAvatarPictureModel* self,
                                                                                                         DinoEntitiesConversation* conversation,
                                                                                                         XmppJid* jid);
VALA_EXTERN XmppXepMucAffiliation dino_ui_model_conference_member_get_affiliation (DinoUiModelConferenceMember* self);
VALA_EXTERN GType dino_ui_view_model_conference_member_list_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUiViewModelConferenceMemberListRow, g_object_unref)
VALA_EXTERN DinoUiViewModelConferenceMemberListRow* dino_ui_view_model_conference_member_list_row_new (void);
VALA_EXTERN DinoUiViewModelConferenceMemberListRow* dino_ui_view_model_conference_member_list_row_construct (GType object_type);
VALA_EXTERN void dino_ui_view_model_conference_member_list_row_set_avatar (DinoUiViewModelConferenceMemberListRow* self,
                                                               DinoUiViewModelCompatAvatarPictureModel* value);
VALA_EXTERN void dino_ui_view_model_conference_member_list_row_set_name (DinoUiViewModelConferenceMemberListRow* self,
                                                             const gchar* value);
VALA_EXTERN void dino_ui_view_model_conference_member_list_row_set_jid (DinoUiViewModelConferenceMemberListRow* self,
                                                            const gchar* value);
VALA_EXTERN void dino_ui_view_model_conference_member_list_row_set_affiliation (DinoUiViewModelConferenceMemberListRow* self,
                                                                    XmppXepMucAffiliation value);
static GObject* ___lambda177__gtk_map_list_model_map_func (GObject* item,
                                                    gpointer self);
VALA_EXTERN void dino_ui_view_model_conversation_details_set_account_jid (DinoUiViewModelConversationDetails* self,
                                                              const gchar* value);
VALA_EXTERN gboolean dino_ui_model_conversation_details_get_domain_blocked (DinoUiModelConversationDetails* self);
VALA_EXTERN GType dino_ui_view_model_conversation_details_block_state_get_type (void) G_GNUC_CONST ;
VALA_EXTERN void dino_ui_view_model_conversation_details_set_blocked (DinoUiViewModelConversationDetails* self,
                                                          DinoUiViewModelConversationDetailsBlockState value);
VALA_EXTERN gboolean dino_ui_model_conversation_details_get_blocked (DinoUiModelConversationDetails* self);
VALA_EXTERN DinoModelConversationDisplayName* dino_ui_model_conversation_details_get_display_name (DinoUiModelConversationDetails* self);
static gboolean __lambda179_ (Block46Data* _data46_,
                       GBinding* _,
                       GValue* from,
                       GValue* to);
VALA_EXTERN GType dino_ui_view_model_conversation_details_notification_setting_get_type (void) G_GNUC_CONST ;
static gboolean ___lambda179__gbinding_transform_func (GBinding* binding,
                                                GValue* from_value,
                                                GValue* to_value,
                                                gpointer self);
static gboolean __lambda180_ (GBinding* _,
                       GValue* from,
                       GValue* to);
static gboolean ___lambda180__gbinding_transform_func (GBinding* binding,
                                                GValue* from_value,
                                                GValue* to_value,
                                                gpointer self);
static gboolean __lambda181_ (GBinding* _,
                       GValue* from,
                       GValue* to);
static gboolean ___lambda181__gbinding_transform_func (GBinding* binding,
                                                GValue* from_value,
                                                GValue* to_value,
                                                gpointer self);
static gboolean __lambda182_ (GBinding* _,
                       GValue* from,
                       GValue* to);
VALA_EXTERN GType dino_ui_view_model_conversation_details_notification_options_get_type (void) G_GNUC_CONST ;
static gboolean ___lambda182__gbinding_transform_func (GBinding* binding,
                                                GValue* from_value,
                                                GValue* to_value,
                                                gpointer self);
static gboolean __lambda183_ (GBinding* _,
                       GValue* from,
                       GValue* to);
VALA_EXTERN GType dino_ui_view_model_preferences_row_any_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUiViewModelPreferencesRowAny, g_object_unref)
VALA_EXTERN DinoUiViewModelPreferencesRowAny* dino_ui_util_get_data_form_field_view_model (XmppXepDataFormsDataFormField* field);
static gboolean ___lambda183__gbinding_transform_func (GBinding* binding,
                                                GValue* from_value,
                                                GValue* to_value,
                                                gpointer self);
static void __lambda185_ (Block46Data* _data46_);
static void ___lambda185__dino_ui_view_model_conversation_details_pin_changed (DinoUiViewModelConversationDetails* _sender,
                                                                        gpointer self);
static void __lambda186_ (Block46Data* _data46_,
                   DinoUiViewModelConversationDetailsBlockState action);
static void ___lambda186__dino_ui_view_model_conversation_details_block_changed (DinoUiViewModelConversationDetails* _sender,
                                                                          DinoUiViewModelConversationDetailsBlockState action,
                                                                          gpointer self);
static void __lambda187_ (Block46Data* _data46_,
                   DinoUiViewModelConversationDetailsNotificationSetting setting);
static void ___lambda187__dino_ui_view_model_conversation_details_notification_changed (DinoUiViewModelConversationDetails* _sender,
                                                                                 DinoUiViewModelConversationDetailsNotificationSetting setting,
                                                                                 gpointer self);
static void __lambda188_ (Block46Data* _data46_);
VALA_EXTERN DinoUiViewModelConversationDetailsNotificationSetting dino_ui_view_model_conversation_details_get_notification (DinoUiViewModelConversationDetails* self);
static void ___lambda188__dino_ui_view_model_conversation_details_notification_flipped (DinoUiViewModelConversationDetails* _sender,
                                                                                 gpointer self);
VALA_EXTERN GType dino_ui_conversation_details_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUiConversationDetailsDialog, g_object_unref)
VALA_EXTERN DinoUiConversationDetailsDialog* dino_ui_conversation_details_setup_dialog (DinoEntitiesConversation* conversation,
                                                                            DinoStreamInteractor* stream_interactor,
                                                                            GtkWindow* parent);
static Block47Data* block47_data_ref (Block47Data* _data47_);
static void block47_data_unref (void * _userdata_);
VALA_EXTERN DinoUiConversationDetailsDialog* dino_ui_conversation_details_dialog_new (void);
VALA_EXTERN DinoUiConversationDetailsDialog* dino_ui_conversation_details_dialog_construct (GType object_type);
VALA_EXTERN DinoUiModelConversationDetails* dino_ui_model_conversation_details_new (void);
VALA_EXTERN DinoUiModelConversationDetails* dino_ui_model_conversation_details_construct (GType object_type);
VALA_EXTERN void dino_ui_model_conversation_details_populate (DinoUiModelConversationDetails* self,
                                                  DinoStreamInteractor* stream_interactor,
                                                  DinoEntitiesConversation* conversation);
VALA_EXTERN DinoUiViewModelConversationDetails* dino_ui_conversation_details_dialog_get_model (DinoUiConversationDetailsDialog* self);
VALA_EXTERN GType dino_ui_view_model_preferences_row_text_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUiViewModelPreferencesRowText, g_object_unref)
VALA_EXTERN DinoUiViewModelPreferencesRowText* dino_ui_view_model_preferences_row_text_new (void);
VALA_EXTERN DinoUiViewModelPreferencesRowText* dino_ui_view_model_preferences_row_text_construct (GType object_type);
VALA_EXTERN void dino_ui_view_model_preferences_row_any_set_title (DinoUiViewModelPreferencesRowAny* self,
                                                       const gchar* value);
VALA_EXTERN void dino_ui_view_model_preferences_row_text_set_text (DinoUiViewModelPreferencesRowText* self,
                                                       const gchar* value);
VALA_EXTERN GType dino_ui_view_model_preferences_row_entry_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUiViewModelPreferencesRowEntry, g_object_unref)
static Block48Data* block48_data_ref (Block48Data* _data48_);
static void block48_data_unref (void * _userdata_);
VALA_EXTERN const gchar* dino_ui_view_model_conversation_details_get_name (DinoUiViewModelConversationDetails* self);
VALA_EXTERN DinoUiViewModelPreferencesRowEntry* dino_ui_view_model_preferences_row_entry_new (void);
VALA_EXTERN DinoUiViewModelPreferencesRowEntry* dino_ui_view_model_preferences_row_entry_construct (GType object_type);
VALA_EXTERN void dino_ui_view_model_preferences_row_entry_set_text (DinoUiViewModelPreferencesRowEntry* self,
                                                        const gchar* value);
static void ___lambda189_ (Block48Data* _data48_);
VALA_EXTERN const gchar* dino_ui_view_model_preferences_row_entry_get_text (DinoUiViewModelPreferencesRowEntry* self);
VALA_EXTERN gchar* dino_ui_util_get_conversation_display_name (DinoStreamInteractor* stream_interactor,
                                                   DinoEntitiesConversation* conversation);
static void ____lambda189__dino_ui_view_model_preferences_row_entry_changed (DinoUiViewModelPreferencesRowEntry* _sender,
                                                                      gpointer self);
VALA_EXTERN gchar* dino_ui_util_parse_add_markup (const gchar* s_,
                                      const gchar* highlight_word,
                                      gboolean parse_links,
                                      gboolean parse_text_markup);
static gboolean __lambda190_ (Block47Data* _data47_);
static gboolean ___lambda190__gtk_window_close_request (GtkWindow* _sender,
                                                 gpointer self);
static void __lambda191_ (Block47Data* _data47_,
                   const gchar* c,
                   const gchar* l,
                   const gchar* d,
                   GObject* wo);
VALA_EXTERN void dino_ui_conversation_details_add_entry (const gchar* category,
                                             const gchar* label,
                                             const gchar* description,
                                             GObject* wo,
                                             DinoUiConversationDetailsDialog* dialog);
static void ___lambda191__dino_plugins_contact_details_add (DinoPluginsContactDetails* _sender,
                                                     const gchar* category,
                                                     const gchar* label,
                                                     const gchar* desc,
                                                     GObject* widget,
                                                     gpointer self);
VALA_EXTERN GType dino_ui_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUiApplication, g_object_unref)
VALA_EXTERN DinoUiContactDetailsSettingsProvider* dino_ui_contact_details_settings_provider_new (DinoStreamInteractor* stream_interactor);
VALA_EXTERN DinoUiContactDetailsSettingsProvider* dino_ui_contact_details_settings_provider_construct (GType object_type,
                                                                                           DinoStreamInteractor* stream_interactor);
VALA_EXTERN GType dino_ui_contact_details_settings_provider_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUiContactDetailsSettingsProvider, g_object_unref)
VALA_EXTERN DinoUiContactDetailsPermissionsProvider* dino_ui_contact_details_permissions_provider_new (DinoStreamInteractor* stream_interactor);
VALA_EXTERN DinoUiContactDetailsPermissionsProvider* dino_ui_contact_details_permissions_provider_construct (GType object_type,
                                                                                                 DinoStreamInteractor* stream_interactor);
VALA_EXTERN GType dino_ui_contact_details_permissions_provider_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUiContactDetailsPermissionsProvider, g_object_unref)
VALA_EXTERN void dino_ui_conversation_details_dialog_add_encryption_tab_element (DinoUiConversationDetailsDialog* self,
                                                                     AdwPreferencesGroup* preferences_group);
VALA_EXTERN GType dino_ui_util_label_hybrid_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUiUtilLabelHybrid, g_object_unref)
VALA_EXTERN GType dino_ui_util_entry_label_hybrid_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUiUtilEntryLabelHybrid, g_object_unref)
VALA_EXTERN DinoUiUtilEntryLabelHybrid* dino_ui_util_entry_label_hybrid_new_wrap (GtkEntry* e);
VALA_EXTERN DinoUiUtilEntryLabelHybrid* dino_ui_util_entry_label_hybrid_construct_wrap (GType object_type,
                                                                            GtkEntry* e);
VALA_EXTERN void dino_ui_util_entry_label_hybrid_set_xalign (DinoUiUtilEntryLabelHybrid* self,
                                                 gfloat value);
VALA_EXTERN GType dino_ui_util_combo_box_text_label_hybrid_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUiUtilComboBoxTextLabelHybrid, g_object_unref)
VALA_EXTERN DinoUiUtilComboBoxTextLabelHybrid* dino_ui_util_combo_box_text_label_hybrid_new_wrap (GtkComboBoxText* cb);
VALA_EXTERN DinoUiUtilComboBoxTextLabelHybrid* dino_ui_util_combo_box_text_label_hybrid_construct_wrap (GType object_type,
                                                                                            GtkComboBoxText* cb);
VALA_EXTERN void dino_ui_util_combo_box_text_label_hybrid_set_xalign (DinoUiUtilComboBoxTextLabelHybrid* self,
                                                          gfloat value);
VALA_EXTERN GType dino_ui_view_model_preferences_row_widget_deprecated_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUiViewModelPreferencesRowWidgetDeprecated, g_object_unref)
VALA_EXTERN DinoUiViewModelPreferencesRowWidgetDeprecated* dino_ui_view_model_preferences_row_widget_deprecated_new (void);
VALA_EXTERN DinoUiViewModelPreferencesRowWidgetDeprecated* dino_ui_view_model_preferences_row_widget_deprecated_construct (GType object_type);
static inline gpointer _vala_memdup2 (gconstpointer mem,
                        gsize byte_size);

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static Block45Data*
block45_data_ref (Block45Data* _data45_)
{
	g_atomic_int_inc (&_data45_->_ref_count_);
	return _data45_;
}

static void
block45_data_unref (void * _userdata_)
{
	Block45Data* _data45_;
	_data45_ = (Block45Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data45_->_ref_count_)) {
		_g_object_unref0 (_data45_->model);
		_g_object_unref0 (_data45_->stream_interactor);
		g_slice_free (Block45Data, _data45_);
	}
}

static void
___lambda176_ (Block45Data* _data45_,
               GObject* _,
               GAsyncResult* res)
{
	DinoModuleIdentity* _tmp0_;
	gpointer _tmp1_;
	DinoMucManager* _tmp2_;
	XmppXepDataFormsDataForm* _tmp3_;
	XmppXepDataFormsDataForm* _tmp4_;
	XmppXepDataFormsDataForm* _tmp5_;
	XmppXepDataFormsDataForm* _tmp6_;
	XmppXepDataFormsDataForm* _tmp7_;
	XmppXepDataFormsDataForm* _tmp8_;
	XmppStanzaNode* _tmp9_;
	XmppStanzaNode* _tmp10_;
	gchar* _tmp11_;
	g_return_if_fail (res != NULL);
	_tmp0_ = dino_muc_manager_IDENTITY;
	_tmp1_ = dino_stream_interactor_get_module (_data45_->stream_interactor, DINO_TYPE_MUC_MANAGER, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _tmp0_);
	_tmp2_ = (DinoMucManager*) _tmp1_;
	_tmp3_ = dino_muc_manager_get_config_form_finish (_tmp2_, res);
	_tmp4_ = _tmp3_;
	dino_ui_model_conversation_details_set_data_form (_data45_->model, _tmp4_);
	_xmpp_xep_data_forms_data_form_unref0 (_tmp4_);
	_g_object_unref0 (_tmp2_);
	_tmp5_ = dino_ui_model_conversation_details_get_data_form (_data45_->model);
	_tmp6_ = _tmp5_;
	if (_tmp6_ == NULL) {
		return;
	}
	_tmp7_ = dino_ui_model_conversation_details_get_data_form (_data45_->model);
	_tmp8_ = _tmp7_;
	_tmp9_ = xmpp_xep_data_forms_data_form_get_stanza_node (_tmp8_);
	_tmp10_ = _tmp9_;
	_tmp11_ = xmpp_stanza_entry_to_string ((XmppStanzaEntry*) _tmp10_, 0);
	_g_free0 (_data45_->model->data_form_bak);
	_data45_->model->data_form_bak = _tmp11_;
}

static void
____lambda176__gasync_ready_callback (GObject* source_object,
                                      GAsyncResult* res,
                                      gpointer self)
{
	___lambda176_ (self, source_object, res);
	block45_data_unref (self);
}

void
dino_ui_conversation_details_populate_dialog (DinoUiModelConversationDetails* model,
                                              DinoEntitiesConversation* conversation,
                                              DinoStreamInteractor* stream_interactor)
{
	Block45Data* _data45_;
	DinoUiModelConversationDetails* _tmp0_;
	DinoStreamInteractor* _tmp1_;
	DinoModuleIdentity* _tmp2_;
	gpointer _tmp3_;
	DinoContactModels* _tmp4_;
	DinoModelConversationDisplayName* _tmp5_;
	DinoModelConversationDisplayName* _tmp6_;
	DinoModuleIdentity* _tmp7_;
	gpointer _tmp8_;
	DinoBlockingManager* _tmp9_;
	DinoEntitiesConversation* _tmp10_;
	DinoEntitiesConversation* _tmp11_;
	DinoEntitiesAccount* _tmp12_;
	DinoEntitiesAccount* _tmp13_;
	DinoEntitiesConversation* _tmp14_;
	DinoEntitiesConversation* _tmp15_;
	XmppJid* _tmp16_;
	XmppJid* _tmp17_;
	DinoModuleIdentity* _tmp18_;
	gpointer _tmp19_;
	DinoBlockingManager* _tmp20_;
	DinoEntitiesConversation* _tmp21_;
	DinoEntitiesConversation* _tmp22_;
	DinoEntitiesAccount* _tmp23_;
	DinoEntitiesAccount* _tmp24_;
	DinoEntitiesConversation* _tmp25_;
	DinoEntitiesConversation* _tmp26_;
	XmppJid* _tmp27_;
	XmppJid* _tmp28_;
	XmppJid* _tmp29_;
	XmppJid* _tmp30_;
	XmppJid* _tmp31_;
	DinoEntitiesConversationType _tmp32_;
	DinoEntitiesConversationType _tmp33_;
	g_return_if_fail (model != NULL);
	g_return_if_fail (conversation != NULL);
	g_return_if_fail (stream_interactor != NULL);
	_data45_ = g_slice_new0 (Block45Data);
	_data45_->_ref_count_ = 1;
	_tmp0_ = _g_object_ref0 (model);
	_g_object_unref0 (_data45_->model);
	_data45_->model = _tmp0_;
	_tmp1_ = _g_object_ref0 (stream_interactor);
	_g_object_unref0 (_data45_->stream_interactor);
	_data45_->stream_interactor = _tmp1_;
	dino_ui_model_conversation_details_set_conversation (_data45_->model, conversation);
	_tmp2_ = dino_contact_models_IDENTITY;
	_tmp3_ = dino_stream_interactor_get_module (_data45_->stream_interactor, DINO_TYPE_CONTACT_MODELS, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _tmp2_);
	_tmp4_ = (DinoContactModels*) _tmp3_;
	_tmp5_ = dino_contact_models_get_display_name_model (_tmp4_, conversation);
	_tmp6_ = _tmp5_;
	dino_ui_model_conversation_details_set_display_name (_data45_->model, _tmp6_);
	_g_object_unref0 (_tmp6_);
	_g_object_unref0 (_tmp4_);
	_tmp7_ = dino_blocking_manager_IDENTITY;
	_tmp8_ = dino_stream_interactor_get_module (_data45_->stream_interactor, DINO_TYPE_BLOCKING_MANAGER, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _tmp7_);
	_tmp9_ = (DinoBlockingManager*) _tmp8_;
	_tmp10_ = dino_ui_model_conversation_details_get_conversation (_data45_->model);
	_tmp11_ = _tmp10_;
	_tmp12_ = dino_entities_conversation_get_account (_tmp11_);
	_tmp13_ = _tmp12_;
	_tmp14_ = dino_ui_model_conversation_details_get_conversation (_data45_->model);
	_tmp15_ = _tmp14_;
	_tmp16_ = dino_entities_conversation_get_counterpart (_tmp15_);
	_tmp17_ = _tmp16_;
	dino_ui_model_conversation_details_set_blocked (_data45_->model, dino_blocking_manager_is_blocked (_tmp9_, _tmp13_, _tmp17_));
	_g_object_unref0 (_tmp9_);
	_tmp18_ = dino_blocking_manager_IDENTITY;
	_tmp19_ = dino_stream_interactor_get_module (_data45_->stream_interactor, DINO_TYPE_BLOCKING_MANAGER, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _tmp18_);
	_tmp20_ = (DinoBlockingManager*) _tmp19_;
	_tmp21_ = dino_ui_model_conversation_details_get_conversation (_data45_->model);
	_tmp22_ = _tmp21_;
	_tmp23_ = dino_entities_conversation_get_account (_tmp22_);
	_tmp24_ = _tmp23_;
	_tmp25_ = dino_ui_model_conversation_details_get_conversation (_data45_->model);
	_tmp26_ = _tmp25_;
	_tmp27_ = dino_entities_conversation_get_counterpart (_tmp26_);
	_tmp28_ = _tmp27_;
	_tmp29_ = xmpp_jid_get_domain_jid (_tmp28_);
	_tmp30_ = _tmp29_;
	_tmp31_ = _tmp30_;
	dino_ui_model_conversation_details_set_domain_blocked (_data45_->model, dino_blocking_manager_is_blocked (_tmp20_, _tmp24_, _tmp31_));
	_xmpp_jid_unref0 (_tmp31_);
	_g_object_unref0 (_tmp20_);
	_tmp32_ = dino_entities_conversation_get_type_ (conversation);
	_tmp33_ = _tmp32_;
	if (_tmp33_ == DINO_ENTITIES_CONVERSATION_TYPE_GROUPCHAT) {
		DinoModuleIdentity* _tmp34_;
		gpointer _tmp35_;
		DinoMucManager* _tmp36_;
		DinoEntitiesAccount* _tmp37_;
		DinoEntitiesAccount* _tmp38_;
		XmppJid* _tmp39_;
		XmppJid* _tmp40_;
		_tmp34_ = dino_muc_manager_IDENTITY;
		_tmp35_ = dino_stream_interactor_get_module (_data45_->stream_interactor, DINO_TYPE_MUC_MANAGER, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _tmp34_);
		_tmp36_ = (DinoMucManager*) _tmp35_;
		_tmp37_ = dino_entities_conversation_get_account (conversation);
		_tmp38_ = _tmp37_;
		_tmp39_ = dino_entities_conversation_get_counterpart (conversation);
		_tmp40_ = _tmp39_;
		dino_muc_manager_get_config_form (_tmp36_, _tmp38_, _tmp40_, ____lambda176__gasync_ready_callback, block45_data_ref (_data45_));
		_g_object_unref0 (_tmp36_);
	}
	block45_data_unref (_data45_);
	_data45_ = NULL;
}

static Block46Data*
block46_data_ref (Block46Data* _data46_)
{
	g_atomic_int_inc (&_data46_->_ref_count_);
	return _data46_;
}

static void
block46_data_unref (void * _userdata_)
{
	Block46Data* _data46_;
	_data46_ = (Block46Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data46_->_ref_count_)) {
		_g_object_unref0 (_data46_->model);
		_g_object_unref0 (_data46_->view_model);
		_g_object_unref0 (_data46_->stream_interactor);
		g_slice_free (Block46Data, _data46_);
	}
}

static GObject*
__lambda177_ (Block46Data* _data46_,
              GObject* item)
{
	DinoUiModelConferenceMember* conference_member = NULL;
	DinoUiModelConferenceMember* _tmp0_;
	XmppJid* nick_jid = NULL;
	DinoModuleIdentity* _tmp1_;
	gpointer _tmp2_;
	DinoMucManager* _tmp3_;
	DinoEntitiesConversation* _tmp4_;
	DinoEntitiesConversation* _tmp5_;
	DinoEntitiesAccount* _tmp6_;
	DinoEntitiesAccount* _tmp7_;
	DinoEntitiesConversation* _tmp8_;
	DinoEntitiesConversation* _tmp9_;
	XmppJid* _tmp10_;
	XmppJid* _tmp11_;
	DinoUiModelConferenceMember* _tmp12_;
	XmppJid* _tmp13_;
	XmppJid* _tmp14_;
	XmppJid* _tmp15_;
	XmppJid* _tmp16_;
	const gchar* _tmp17_ = NULL;
	XmppJid* _tmp18_;
	DinoUiViewModelCompatAvatarPictureModel* _tmp25_;
	DinoUiViewModelCompatAvatarPictureModel* _tmp26_;
	DinoEntitiesConversation* _tmp27_;
	DinoEntitiesConversation* _tmp28_;
	DinoUiModelConferenceMember* _tmp29_;
	XmppJid* _tmp30_;
	XmppJid* _tmp31_;
	DinoUiViewModelCompatAvatarPictureModel* _tmp32_;
	gchar* _tmp33_;
	DinoUiModelConferenceMember* _tmp34_;
	XmppJid* _tmp35_;
	XmppJid* _tmp36_;
	gchar* _tmp37_;
	DinoUiModelConferenceMember* _tmp38_;
	XmppXepMucAffiliation _tmp39_;
	XmppXepMucAffiliation _tmp40_;
	DinoUiViewModelConferenceMemberListRow* _tmp41_ = NULL;
	GObject* _tmp42_;
	GObject* result;
	g_return_val_if_fail (item != NULL, NULL);
	_tmp0_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (item, DINO_UI_MODEL_TYPE_CONFERENCE_MEMBER, DinoUiModelConferenceMember));
	conference_member = _tmp0_;
	_tmp1_ = dino_muc_manager_IDENTITY;
	_tmp2_ = dino_stream_interactor_get_module (_data46_->stream_interactor, DINO_TYPE_MUC_MANAGER, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _tmp1_);
	_tmp3_ = (DinoMucManager*) _tmp2_;
	_tmp4_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
	_tmp5_ = _tmp4_;
	_tmp6_ = dino_entities_conversation_get_account (_tmp5_);
	_tmp7_ = _tmp6_;
	_tmp8_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
	_tmp9_ = _tmp8_;
	_tmp10_ = dino_entities_conversation_get_counterpart (_tmp9_);
	_tmp11_ = _tmp10_;
	_tmp12_ = conference_member;
	_tmp13_ = dino_ui_model_conference_member_get_jid (_tmp12_);
	_tmp14_ = _tmp13_;
	_tmp15_ = dino_muc_manager_get_occupant_jid (_tmp3_, _tmp7_, _tmp11_, _tmp14_);
	_tmp16_ = _tmp15_;
	_g_object_unref0 (_tmp3_);
	nick_jid = _tmp16_;
	_tmp18_ = nick_jid;
	if (_tmp18_ != NULL) {
		XmppJid* _tmp19_;
		const gchar* _tmp20_;
		_tmp19_ = nick_jid;
		_tmp20_ = _tmp19_->resourcepart;
		_tmp17_ = _tmp20_;
	} else {
		DinoUiModelConferenceMember* _tmp21_;
		XmppJid* _tmp22_;
		XmppJid* _tmp23_;
		const gchar* _tmp24_;
		_tmp21_ = conference_member;
		_tmp22_ = dino_ui_model_conference_member_get_jid (_tmp21_);
		_tmp23_ = _tmp22_;
		_tmp24_ = _tmp23_->localpart;
		_tmp17_ = _tmp24_;
	}
	_tmp25_ = dino_ui_view_model_compat_avatar_picture_model_new (_data46_->stream_interactor);
	_tmp26_ = _tmp25_;
	_tmp27_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
	_tmp28_ = _tmp27_;
	_tmp29_ = conference_member;
	_tmp30_ = dino_ui_model_conference_member_get_jid (_tmp29_);
	_tmp31_ = _tmp30_;
	_tmp32_ = dino_ui_view_model_compat_avatar_picture_model_add_participant (_tmp26_, _tmp28_, _tmp31_);
	_tmp33_ = g_strdup (_tmp17_);
	_tmp34_ = conference_member;
	_tmp35_ = dino_ui_model_conference_member_get_jid (_tmp34_);
	_tmp36_ = _tmp35_;
	_tmp37_ = xmpp_jid_to_string (_tmp36_);
	_tmp38_ = conference_member;
	_tmp39_ = dino_ui_model_conference_member_get_affiliation (_tmp38_);
	_tmp40_ = _tmp39_;
	_tmp41_ = dino_ui_view_model_conference_member_list_row_new ();
	dino_ui_view_model_conference_member_list_row_set_avatar (_tmp41_, _tmp32_);
	_g_object_unref0 (_tmp32_);
	dino_ui_view_model_conference_member_list_row_set_name (_tmp41_, _tmp33_);
	_g_free0 (_tmp33_);
	dino_ui_view_model_conference_member_list_row_set_jid (_tmp41_, _tmp37_);
	_g_free0 (_tmp37_);
	dino_ui_view_model_conference_member_list_row_set_affiliation (_tmp41_, _tmp40_);
	_tmp42_ = (GObject*) _tmp41_;
	_g_object_unref0 (_tmp26_);
	result = _tmp42_;
	_xmpp_jid_unref0 (nick_jid);
	_g_object_unref0 (conference_member);
	_g_object_unref0 (item);
	return result;
}

static GObject*
___lambda177__gtk_map_list_model_map_func (GObject* item,
                                           gpointer self)
{
	GObject* result;
	result = __lambda177_ (self, item);
	return result;
}

static gboolean
__lambda179_ (Block46Data* _data46_,
              GBinding* _,
              GValue* from,
              GValue* to)
{
	DinoEntitiesConversation* _tmp0_;
	DinoEntitiesConversation* _tmp1_;
	gboolean result;
	g_return_val_if_fail (_ != NULL, FALSE);
	g_return_val_if_fail (from != NULL, FALSE);
	g_return_val_if_fail (to != NULL, FALSE);
	_tmp0_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
	_tmp1_ = _tmp0_;
	switch (dino_entities_conversation_get_notification_setting (_tmp1_, _data46_->stream_interactor)) {
		case DINO_ENTITIES_CONVERSATION_NOTIFY_SETTING_ON:
		{
			GValue _tmp2_ = {0};
			g_value_init (&_tmp2_, DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_TYPE_NOTIFICATION_SETTING);
			g_value_set_enum (&_tmp2_, DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_NOTIFICATION_SETTING_ON);
			G_IS_VALUE (to) ? (g_value_unset (to), NULL) : NULL;
			*to = _tmp2_;
			break;
		}
		case DINO_ENTITIES_CONVERSATION_NOTIFY_SETTING_OFF:
		{
			GValue _tmp3_ = {0};
			g_value_init (&_tmp3_, DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_TYPE_NOTIFICATION_SETTING);
			g_value_set_enum (&_tmp3_, DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_NOTIFICATION_SETTING_OFF);
			G_IS_VALUE (to) ? (g_value_unset (to), NULL) : NULL;
			*to = _tmp3_;
			break;
		}
		case DINO_ENTITIES_CONVERSATION_NOTIFY_SETTING_HIGHLIGHT:
		{
			GValue _tmp4_ = {0};
			g_value_init (&_tmp4_, DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_TYPE_NOTIFICATION_SETTING);
			g_value_set_enum (&_tmp4_, DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_NOTIFICATION_SETTING_HIGHLIGHT);
			G_IS_VALUE (to) ? (g_value_unset (to), NULL) : NULL;
			*to = _tmp4_;
			break;
		}
		case DINO_ENTITIES_CONVERSATION_NOTIFY_SETTING_DEFAULT:
		{
			g_assert_not_reached ();
		}
		default:
		break;
	}
	result = TRUE;
	return result;
}

static gboolean
___lambda179__gbinding_transform_func (GBinding* binding,
                                       GValue* from_value,
                                       GValue* to_value,
                                       gpointer self)
{
	gboolean result;
	result = __lambda179_ (self, binding, from_value, to_value);
	return result;
}

static gboolean
__lambda180_ (GBinding* _,
              GValue* from,
              GValue* to)
{
	DinoEntitiesConversationNotifySetting notify_setting = 0;
	GValue _tmp0_;
	GValue _tmp1_ = {0};
	gboolean result;
	g_return_val_if_fail (_ != NULL, FALSE);
	g_return_val_if_fail (from != NULL, FALSE);
	g_return_val_if_fail (to != NULL, FALSE);
	_tmp0_ = *from;
	notify_setting = g_value_get_enum (&_tmp0_);
	g_value_init (&_tmp1_, G_TYPE_BOOLEAN);
	g_value_set_boolean (&_tmp1_, notify_setting == DINO_ENTITIES_CONVERSATION_NOTIFY_SETTING_DEFAULT);
	G_IS_VALUE (to) ? (g_value_unset (to), NULL) : NULL;
	*to = _tmp1_;
	result = TRUE;
	return result;
}

static gboolean
___lambda180__gbinding_transform_func (GBinding* binding,
                                       GValue* from_value,
                                       GValue* to_value,
                                       gpointer self)
{
	gboolean result;
	result = __lambda180_ (binding, from_value, to_value);
	return result;
}

static gboolean
__lambda181_ (GBinding* _,
              GValue* from,
              GValue* to)
{
	gint from_int = 0;
	GValue _tmp0_;
	GValue _tmp1_ = {0};
	gboolean result;
	g_return_val_if_fail (_ != NULL, FALSE);
	g_return_val_if_fail (from != NULL, FALSE);
	g_return_val_if_fail (to != NULL, FALSE);
	_tmp0_ = *from;
	from_int = g_value_get_int (&_tmp0_);
	g_value_init (&_tmp1_, G_TYPE_BOOLEAN);
	g_value_set_boolean (&_tmp1_, from_int > 0);
	G_IS_VALUE (to) ? (g_value_unset (to), NULL) : NULL;
	*to = _tmp1_;
	result = TRUE;
	return result;
}

static gboolean
___lambda181__gbinding_transform_func (GBinding* binding,
                                       GValue* from_value,
                                       GValue* to_value,
                                       gpointer self)
{
	gboolean result;
	result = __lambda181_ (binding, from_value, to_value);
	return result;
}

static gboolean
__lambda182_ (GBinding* _,
              GValue* from,
              GValue* to)
{
	DinoEntitiesConversationType ty = 0;
	GValue _tmp0_;
	DinoUiViewModelConversationDetailsNotificationOptions _tmp1_ = 0;
	GValue _tmp2_ = {0};
	gboolean result;
	g_return_val_if_fail (_ != NULL, FALSE);
	g_return_val_if_fail (from != NULL, FALSE);
	g_return_val_if_fail (to != NULL, FALSE);
	_tmp0_ = *from;
	ty = g_value_get_enum (&_tmp0_);
	if (ty == DINO_ENTITIES_CONVERSATION_TYPE_GROUPCHAT) {
		_tmp1_ = DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_NOTIFICATION_OPTIONS_ON_HIGHLIGHT_OFF;
	} else {
		_tmp1_ = DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_NOTIFICATION_OPTIONS_ON_OFF;
	}
	g_value_init (&_tmp2_, DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_TYPE_NOTIFICATION_OPTIONS);
	g_value_set_enum (&_tmp2_, _tmp1_);
	G_IS_VALUE (to) ? (g_value_unset (to), NULL) : NULL;
	*to = _tmp2_;
	result = TRUE;
	return result;
}

static gboolean
___lambda182__gbinding_transform_func (GBinding* binding,
                                       GValue* from_value,
                                       GValue* to_value,
                                       gpointer self)
{
	gboolean result;
	result = __lambda182_ (binding, from_value, to_value);
	return result;
}

static gpointer
_xmpp_xep_data_forms_data_form_ref0 (gpointer self)
{
	return self ? xmpp_xep_data_forms_data_form_ref (self) : NULL;
}

static gboolean
__lambda183_ (GBinding* _,
              GValue* from,
              GValue* to)
{
	XmppXepDataFormsDataForm* data_form = NULL;
	GValue _tmp0_;
	XmppXepDataFormsDataForm* _tmp1_;
	XmppXepDataFormsDataForm* _tmp2_;
	GListStore* list_store = NULL;
	GListStore* _tmp3_;
	GListStore* _tmp18_;
	GValue _tmp19_ = {0};
	gboolean result;
	g_return_val_if_fail (_ != NULL, FALSE);
	g_return_val_if_fail (from != NULL, FALSE);
	g_return_val_if_fail (to != NULL, FALSE);
	_tmp0_ = *from;
	_tmp1_ = _xmpp_xep_data_forms_data_form_ref0 (xmpp_xep_data_forms_value_get_data_form (&_tmp0_));
	data_form = _tmp1_;
	_tmp2_ = data_form;
	if (_tmp2_ == NULL) {
		result = TRUE;
		_xmpp_xep_data_forms_data_form_unref0 (data_form);
		return result;
	}
	_tmp3_ = g_list_store_new (DINO_UI_VIEW_MODEL_PREFERENCES_ROW_TYPE_ANY);
	list_store = _tmp3_;
	{
		GeeList* _field_list = NULL;
		XmppXepDataFormsDataForm* _tmp4_;
		GeeList* _tmp5_;
		gint _field_size = 0;
		GeeList* _tmp6_;
		gint _tmp7_;
		gint _tmp8_;
		gint _field_index = 0;
		_tmp4_ = data_form;
		_tmp5_ = _tmp4_->fields;
		_field_list = _tmp5_;
		_tmp6_ = _field_list;
		_tmp7_ = gee_collection_get_size ((GeeCollection*) _tmp6_);
		_tmp8_ = _tmp7_;
		_field_size = _tmp8_;
		_field_index = -1;
		while (TRUE) {
			gint _tmp9_;
			gint _tmp10_;
			XmppXepDataFormsDataFormField* field = NULL;
			GeeList* _tmp11_;
			gpointer _tmp12_;
			DinoUiViewModelPreferencesRowAny* field_view_model = NULL;
			XmppXepDataFormsDataFormField* _tmp13_;
			DinoUiViewModelPreferencesRowAny* _tmp14_;
			DinoUiViewModelPreferencesRowAny* _tmp15_;
			_field_index = _field_index + 1;
			_tmp9_ = _field_index;
			_tmp10_ = _field_size;
			if (!(_tmp9_ < _tmp10_)) {
				break;
			}
			_tmp11_ = _field_list;
			_tmp12_ = gee_list_get (_tmp11_, _field_index);
			field = (XmppXepDataFormsDataFormField*) _tmp12_;
			_tmp13_ = field;
			_tmp14_ = dino_ui_util_get_data_form_field_view_model (_tmp13_);
			field_view_model = _tmp14_;
			_tmp15_ = field_view_model;
			if (_tmp15_ != NULL) {
				GListStore* _tmp16_;
				DinoUiViewModelPreferencesRowAny* _tmp17_;
				_tmp16_ = list_store;
				_tmp17_ = field_view_model;
				g_list_store_append (_tmp16_, (GObject*) _tmp17_);
			}
			_g_object_unref0 (field_view_model);
			_g_object_unref0 (field);
		}
	}
	_tmp18_ = list_store;
	g_value_init (&_tmp19_, g_list_store_get_type ());
	g_value_set_object (&_tmp19_, _tmp18_);
	G_IS_VALUE (to) ? (g_value_unset (to), NULL) : NULL;
	*to = _tmp19_;
	result = TRUE;
	_g_object_unref0 (list_store);
	_xmpp_xep_data_forms_data_form_unref0 (data_form);
	return result;
}

static gboolean
___lambda183__gbinding_transform_func (GBinding* binding,
                                       GValue* from_value,
                                       GValue* to_value,
                                       gpointer self)
{
	gboolean result;
	result = __lambda183_ (binding, from_value, to_value);
	return result;
}

static void
__lambda185_ (Block46Data* _data46_)
{
	gint _tmp0_ = 0;
	DinoEntitiesConversation* _tmp1_;
	DinoEntitiesConversation* _tmp2_;
	gint _tmp3_;
	gint _tmp4_;
	DinoEntitiesConversation* _tmp5_;
	DinoEntitiesConversation* _tmp6_;
	_tmp1_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
	_tmp2_ = _tmp1_;
	_tmp3_ = dino_entities_conversation_get_pinned (_tmp2_);
	_tmp4_ = _tmp3_;
	if (_tmp4_ == 1) {
		_tmp0_ = 0;
	} else {
		_tmp0_ = 1;
	}
	_tmp5_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
	_tmp6_ = _tmp5_;
	dino_entities_conversation_set_pinned (_tmp6_, _tmp0_);
}

static void
___lambda185__dino_ui_view_model_conversation_details_pin_changed (DinoUiViewModelConversationDetails* _sender,
                                                                   gpointer self)
{
	__lambda185_ (self);
}

static void
__lambda186_ (Block46Data* _data46_,
              DinoUiViewModelConversationDetailsBlockState action)
{
	switch (action) {
		case DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_BLOCK_STATE_USER:
		{
			DinoModuleIdentity* _tmp0_;
			gpointer _tmp1_;
			DinoBlockingManager* _tmp2_;
			DinoEntitiesConversation* _tmp3_;
			DinoEntitiesConversation* _tmp4_;
			DinoEntitiesAccount* _tmp5_;
			DinoEntitiesAccount* _tmp6_;
			DinoEntitiesConversation* _tmp7_;
			DinoEntitiesConversation* _tmp8_;
			XmppJid* _tmp9_;
			XmppJid* _tmp10_;
			DinoModuleIdentity* _tmp11_;
			gpointer _tmp12_;
			DinoBlockingManager* _tmp13_;
			DinoEntitiesConversation* _tmp14_;
			DinoEntitiesConversation* _tmp15_;
			DinoEntitiesAccount* _tmp16_;
			DinoEntitiesAccount* _tmp17_;
			DinoEntitiesConversation* _tmp18_;
			DinoEntitiesConversation* _tmp19_;
			XmppJid* _tmp20_;
			XmppJid* _tmp21_;
			XmppJid* _tmp22_;
			XmppJid* _tmp23_;
			XmppJid* _tmp24_;
			_tmp0_ = dino_blocking_manager_IDENTITY;
			_tmp1_ = dino_stream_interactor_get_module (_data46_->stream_interactor, DINO_TYPE_BLOCKING_MANAGER, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _tmp0_);
			_tmp2_ = (DinoBlockingManager*) _tmp1_;
			_tmp3_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
			_tmp4_ = _tmp3_;
			_tmp5_ = dino_entities_conversation_get_account (_tmp4_);
			_tmp6_ = _tmp5_;
			_tmp7_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
			_tmp8_ = _tmp7_;
			_tmp9_ = dino_entities_conversation_get_counterpart (_tmp8_);
			_tmp10_ = _tmp9_;
			dino_blocking_manager_block (_tmp2_, _tmp6_, _tmp10_);
			_g_object_unref0 (_tmp2_);
			_tmp11_ = dino_blocking_manager_IDENTITY;
			_tmp12_ = dino_stream_interactor_get_module (_data46_->stream_interactor, DINO_TYPE_BLOCKING_MANAGER, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _tmp11_);
			_tmp13_ = (DinoBlockingManager*) _tmp12_;
			_tmp14_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
			_tmp15_ = _tmp14_;
			_tmp16_ = dino_entities_conversation_get_account (_tmp15_);
			_tmp17_ = _tmp16_;
			_tmp18_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
			_tmp19_ = _tmp18_;
			_tmp20_ = dino_entities_conversation_get_counterpart (_tmp19_);
			_tmp21_ = _tmp20_;
			_tmp22_ = xmpp_jid_get_domain_jid (_tmp21_);
			_tmp23_ = _tmp22_;
			_tmp24_ = _tmp23_;
			dino_blocking_manager_unblock (_tmp13_, _tmp17_, _tmp24_);
			_xmpp_jid_unref0 (_tmp24_);
			_g_object_unref0 (_tmp13_);
			break;
		}
		case DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_BLOCK_STATE_DOMAIN:
		{
			DinoModuleIdentity* _tmp25_;
			gpointer _tmp26_;
			DinoBlockingManager* _tmp27_;
			DinoEntitiesConversation* _tmp28_;
			DinoEntitiesConversation* _tmp29_;
			DinoEntitiesAccount* _tmp30_;
			DinoEntitiesAccount* _tmp31_;
			DinoEntitiesConversation* _tmp32_;
			DinoEntitiesConversation* _tmp33_;
			XmppJid* _tmp34_;
			XmppJid* _tmp35_;
			XmppJid* _tmp36_;
			XmppJid* _tmp37_;
			XmppJid* _tmp38_;
			_tmp25_ = dino_blocking_manager_IDENTITY;
			_tmp26_ = dino_stream_interactor_get_module (_data46_->stream_interactor, DINO_TYPE_BLOCKING_MANAGER, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _tmp25_);
			_tmp27_ = (DinoBlockingManager*) _tmp26_;
			_tmp28_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
			_tmp29_ = _tmp28_;
			_tmp30_ = dino_entities_conversation_get_account (_tmp29_);
			_tmp31_ = _tmp30_;
			_tmp32_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
			_tmp33_ = _tmp32_;
			_tmp34_ = dino_entities_conversation_get_counterpart (_tmp33_);
			_tmp35_ = _tmp34_;
			_tmp36_ = xmpp_jid_get_domain_jid (_tmp35_);
			_tmp37_ = _tmp36_;
			_tmp38_ = _tmp37_;
			dino_blocking_manager_block (_tmp27_, _tmp31_, _tmp38_);
			_xmpp_jid_unref0 (_tmp38_);
			_g_object_unref0 (_tmp27_);
			break;
		}
		case DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_BLOCK_STATE_UNBLOCK:
		{
			DinoModuleIdentity* _tmp39_;
			gpointer _tmp40_;
			DinoBlockingManager* _tmp41_;
			DinoEntitiesConversation* _tmp42_;
			DinoEntitiesConversation* _tmp43_;
			DinoEntitiesAccount* _tmp44_;
			DinoEntitiesAccount* _tmp45_;
			DinoEntitiesConversation* _tmp46_;
			DinoEntitiesConversation* _tmp47_;
			XmppJid* _tmp48_;
			XmppJid* _tmp49_;
			DinoModuleIdentity* _tmp50_;
			gpointer _tmp51_;
			DinoBlockingManager* _tmp52_;
			DinoEntitiesConversation* _tmp53_;
			DinoEntitiesConversation* _tmp54_;
			DinoEntitiesAccount* _tmp55_;
			DinoEntitiesAccount* _tmp56_;
			DinoEntitiesConversation* _tmp57_;
			DinoEntitiesConversation* _tmp58_;
			XmppJid* _tmp59_;
			XmppJid* _tmp60_;
			XmppJid* _tmp61_;
			XmppJid* _tmp62_;
			XmppJid* _tmp63_;
			_tmp39_ = dino_blocking_manager_IDENTITY;
			_tmp40_ = dino_stream_interactor_get_module (_data46_->stream_interactor, DINO_TYPE_BLOCKING_MANAGER, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _tmp39_);
			_tmp41_ = (DinoBlockingManager*) _tmp40_;
			_tmp42_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
			_tmp43_ = _tmp42_;
			_tmp44_ = dino_entities_conversation_get_account (_tmp43_);
			_tmp45_ = _tmp44_;
			_tmp46_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
			_tmp47_ = _tmp46_;
			_tmp48_ = dino_entities_conversation_get_counterpart (_tmp47_);
			_tmp49_ = _tmp48_;
			dino_blocking_manager_unblock (_tmp41_, _tmp45_, _tmp49_);
			_g_object_unref0 (_tmp41_);
			_tmp50_ = dino_blocking_manager_IDENTITY;
			_tmp51_ = dino_stream_interactor_get_module (_data46_->stream_interactor, DINO_TYPE_BLOCKING_MANAGER, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _tmp50_);
			_tmp52_ = (DinoBlockingManager*) _tmp51_;
			_tmp53_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
			_tmp54_ = _tmp53_;
			_tmp55_ = dino_entities_conversation_get_account (_tmp54_);
			_tmp56_ = _tmp55_;
			_tmp57_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
			_tmp58_ = _tmp57_;
			_tmp59_ = dino_entities_conversation_get_counterpart (_tmp58_);
			_tmp60_ = _tmp59_;
			_tmp61_ = xmpp_jid_get_domain_jid (_tmp60_);
			_tmp62_ = _tmp61_;
			_tmp63_ = _tmp62_;
			dino_blocking_manager_unblock (_tmp52_, _tmp56_, _tmp63_);
			_xmpp_jid_unref0 (_tmp63_);
			_g_object_unref0 (_tmp52_);
			break;
		}
		default:
		break;
	}
	dino_ui_view_model_conversation_details_set_blocked (_data46_->view_model, action);
}

static void
___lambda186__dino_ui_view_model_conversation_details_block_changed (DinoUiViewModelConversationDetails* _sender,
                                                                     DinoUiViewModelConversationDetailsBlockState action,
                                                                     gpointer self)
{
	__lambda186_ (self, action);
}

static void
__lambda187_ (Block46Data* _data46_,
              DinoUiViewModelConversationDetailsNotificationSetting setting)
{
	switch (setting) {
		case DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_NOTIFICATION_SETTING_ON:
		{
			DinoEntitiesConversation* _tmp0_;
			DinoEntitiesConversation* _tmp1_;
			_tmp0_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
			_tmp1_ = _tmp0_;
			dino_entities_conversation_set_notify_setting (_tmp1_, DINO_ENTITIES_CONVERSATION_NOTIFY_SETTING_ON);
			break;
		}
		case DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_NOTIFICATION_SETTING_OFF:
		{
			DinoEntitiesConversation* _tmp2_;
			DinoEntitiesConversation* _tmp3_;
			_tmp2_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
			_tmp3_ = _tmp2_;
			dino_entities_conversation_set_notify_setting (_tmp3_, DINO_ENTITIES_CONVERSATION_NOTIFY_SETTING_OFF);
			break;
		}
		case DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_NOTIFICATION_SETTING_HIGHLIGHT:
		{
			DinoEntitiesConversation* _tmp4_;
			DinoEntitiesConversation* _tmp5_;
			_tmp4_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
			_tmp5_ = _tmp4_;
			dino_entities_conversation_set_notify_setting (_tmp5_, DINO_ENTITIES_CONVERSATION_NOTIFY_SETTING_HIGHLIGHT);
			break;
		}
		case DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_NOTIFICATION_SETTING_DEFAULT:
		{
			DinoEntitiesConversation* _tmp6_;
			DinoEntitiesConversation* _tmp7_;
			_tmp6_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
			_tmp7_ = _tmp6_;
			dino_entities_conversation_set_notify_setting (_tmp7_, DINO_ENTITIES_CONVERSATION_NOTIFY_SETTING_DEFAULT);
			break;
		}
		default:
		break;
	}
}

static void
___lambda187__dino_ui_view_model_conversation_details_notification_changed (DinoUiViewModelConversationDetails* _sender,
                                                                            DinoUiViewModelConversationDetailsNotificationSetting setting,
                                                                            gpointer self)
{
	__lambda187_ (self, setting);
}

static void
__lambda188_ (Block46Data* _data46_)
{
	DinoEntitiesConversationNotifySetting _tmp0_ = 0;
	DinoUiViewModelConversationDetailsNotificationSetting _tmp1_;
	DinoUiViewModelConversationDetailsNotificationSetting _tmp2_;
	DinoEntitiesConversation* _tmp3_;
	DinoEntitiesConversation* _tmp4_;
	_tmp1_ = dino_ui_view_model_conversation_details_get_notification (_data46_->view_model);
	_tmp2_ = _tmp1_;
	if (_tmp2_ == DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_NOTIFICATION_SETTING_ON) {
		_tmp0_ = DINO_ENTITIES_CONVERSATION_NOTIFY_SETTING_OFF;
	} else {
		_tmp0_ = DINO_ENTITIES_CONVERSATION_NOTIFY_SETTING_ON;
	}
	_tmp3_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
	_tmp4_ = _tmp3_;
	dino_entities_conversation_set_notify_setting (_tmp4_, _tmp0_);
}

static void
___lambda188__dino_ui_view_model_conversation_details_notification_flipped (DinoUiViewModelConversationDetails* _sender,
                                                                            gpointer self)
{
	__lambda188_ (self);
}

void
dino_ui_conversation_details_bind_dialog (DinoUiModelConversationDetails* model,
                                          DinoUiViewModelConversationDetails* view_model,
                                          DinoStreamInteractor* stream_interactor)
{
	Block46Data* _data46_;
	DinoUiModelConversationDetails* _tmp0_;
	DinoUiViewModelConversationDetails* _tmp1_;
	DinoStreamInteractor* _tmp2_;
	DinoUiViewModelCompatAvatarPictureModel* _tmp3_;
	DinoUiViewModelCompatAvatarPictureModel* _tmp4_;
	DinoEntitiesConversation* _tmp5_;
	DinoEntitiesConversation* _tmp6_;
	DinoUiViewModelCompatAvatarPictureModel* _tmp7_;
	DinoUiViewModelCompatAvatarPictureModel* _tmp8_;
	gboolean _tmp9_ = FALSE;
	DinoEntitiesConversation* _tmp10_;
	DinoEntitiesConversation* _tmp11_;
	DinoEntitiesConversationType _tmp12_;
	DinoEntitiesConversationType _tmp13_;
	GtkSortListModel* _tmp21_;
	GListStore* _tmp22_;
	GtkMapListModel* _tmp23_;
	gchar* _tmp24_ = NULL;
	GeeArrayList* _tmp25_;
	GeeArrayList* _tmp26_;
	gint _tmp27_;
	gint _tmp28_;
	gboolean _tmp29_;
	gboolean _tmp38_;
	gboolean _tmp39_;
	DinoModelConversationDisplayName* _tmp42_;
	DinoModelConversationDisplayName* _tmp43_;
	DinoEntitiesConversation* _tmp44_;
	DinoEntitiesConversation* _tmp45_;
	DinoEntitiesConversation* _tmp46_;
	DinoEntitiesConversation* _tmp47_;
	DinoEntitiesConversation* _tmp48_;
	DinoEntitiesConversation* _tmp49_;
	DinoEntitiesConversation* _tmp50_;
	DinoEntitiesConversation* _tmp51_;
	g_return_if_fail (model != NULL);
	g_return_if_fail (view_model != NULL);
	g_return_if_fail (stream_interactor != NULL);
	_data46_ = g_slice_new0 (Block46Data);
	_data46_->_ref_count_ = 1;
	_tmp0_ = _g_object_ref0 (model);
	_g_object_unref0 (_data46_->model);
	_data46_->model = _tmp0_;
	_tmp1_ = _g_object_ref0 (view_model);
	_g_object_unref0 (_data46_->view_model);
	_data46_->view_model = _tmp1_;
	_tmp2_ = _g_object_ref0 (stream_interactor);
	_g_object_unref0 (_data46_->stream_interactor);
	_data46_->stream_interactor = _tmp2_;
	_tmp3_ = dino_ui_view_model_compat_avatar_picture_model_new (_data46_->stream_interactor);
	_tmp4_ = _tmp3_;
	_tmp5_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
	_tmp6_ = _tmp5_;
	_tmp7_ = dino_ui_view_model_compat_avatar_picture_model_set_conversation (_tmp4_, _tmp6_);
	_tmp8_ = _tmp7_;
	dino_ui_view_model_conversation_details_set_avatar (_data46_->view_model, _tmp8_);
	_g_object_unref0 (_tmp8_);
	_g_object_unref0 (_tmp4_);
	_tmp10_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
	_tmp11_ = _tmp10_;
	_tmp12_ = dino_entities_conversation_get_type_ (_tmp11_);
	_tmp13_ = _tmp12_;
	if (_tmp13_ == DINO_ENTITIES_CONVERSATION_TYPE_CHAT) {
		DinoModuleIdentity* _tmp14_;
		gpointer _tmp15_;
		DinoBlockingManager* _tmp16_;
		DinoEntitiesConversation* _tmp17_;
		DinoEntitiesConversation* _tmp18_;
		DinoEntitiesAccount* _tmp19_;
		DinoEntitiesAccount* _tmp20_;
		_tmp14_ = dino_blocking_manager_IDENTITY;
		_tmp15_ = dino_stream_interactor_get_module (_data46_->stream_interactor, DINO_TYPE_BLOCKING_MANAGER, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _tmp14_);
		_tmp16_ = (DinoBlockingManager*) _tmp15_;
		_tmp17_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
		_tmp18_ = _tmp17_;
		_tmp19_ = dino_entities_conversation_get_account (_tmp18_);
		_tmp20_ = _tmp19_;
		_tmp9_ = dino_blocking_manager_is_supported (_tmp16_, _tmp20_);
		_g_object_unref0 (_tmp16_);
	} else {
		_tmp9_ = FALSE;
	}
	dino_ui_view_model_conversation_details_set_show_blocked (_data46_->view_model, _tmp9_);
	_tmp21_ = _data46_->view_model->members_sorted;
	_tmp22_ = _data46_->model->members;
	gtk_sort_list_model_set_model (_tmp21_, (GListModel*) _tmp22_);
	_tmp23_ = _data46_->view_model->members;
	gtk_map_list_model_set_map_func (_tmp23_, ___lambda177__gtk_map_list_model_map_func, block46_data_ref (_data46_), block46_data_unref);
	_tmp25_ = dino_stream_interactor_get_accounts (_data46_->stream_interactor);
	_tmp26_ = _tmp25_;
	_tmp27_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp26_);
	_tmp28_ = _tmp27_;
	_tmp29_ = _tmp28_ > 1;
	_g_object_unref0 (_tmp26_);
	if (_tmp29_) {
		DinoEntitiesConversation* _tmp30_;
		DinoEntitiesConversation* _tmp31_;
		DinoEntitiesAccount* _tmp32_;
		DinoEntitiesAccount* _tmp33_;
		XmppJid* _tmp34_;
		XmppJid* _tmp35_;
		XmppJid* _tmp36_;
		gchar* _tmp37_;
		_tmp30_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
		_tmp31_ = _tmp30_;
		_tmp32_ = dino_entities_conversation_get_account (_tmp31_);
		_tmp33_ = _tmp32_;
		_tmp34_ = dino_entities_account_get_bare_jid (_tmp33_);
		_tmp35_ = _tmp34_;
		_tmp36_ = _tmp35_;
		_tmp37_ = xmpp_jid_to_string (_tmp36_);
		_g_free0 (_tmp24_);
		_tmp24_ = _tmp37_;
		_xmpp_jid_unref0 (_tmp36_);
	} else {
		_g_free0 (_tmp24_);
		_tmp24_ = NULL;
	}
	dino_ui_view_model_conversation_details_set_account_jid (_data46_->view_model, _tmp24_);
	_tmp38_ = dino_ui_model_conversation_details_get_domain_blocked (_data46_->model);
	_tmp39_ = _tmp38_;
	if (_tmp39_) {
		dino_ui_view_model_conversation_details_set_blocked (_data46_->view_model, DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_BLOCK_STATE_DOMAIN);
	} else {
		gboolean _tmp40_;
		gboolean _tmp41_;
		_tmp40_ = dino_ui_model_conversation_details_get_blocked (_data46_->model);
		_tmp41_ = _tmp40_;
		if (_tmp41_) {
			dino_ui_view_model_conversation_details_set_blocked (_data46_->view_model, DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_BLOCK_STATE_USER);
		} else {
			dino_ui_view_model_conversation_details_set_blocked (_data46_->view_model, DINO_UI_VIEW_MODEL_CONVERSATION_DETAILS_BLOCK_STATE_UNBLOCK);
		}
	}
	_tmp42_ = dino_ui_model_conversation_details_get_display_name (_data46_->model);
	_tmp43_ = _tmp42_;
	g_object_bind_property_with_closures ((GObject*) _tmp43_, "display-name", (GObject*) _data46_->view_model, "name", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	_tmp44_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
	_tmp45_ = _tmp44_;
	g_object_bind_property_with_closures ((GObject*) _tmp45_, "notify-setting", (GObject*) _data46_->view_model, "notification", G_BINDING_SYNC_CREATE, (GClosure*) ((___lambda179__gbinding_transform_func == NULL) ? NULL : g_cclosure_new ((GCallback) ___lambda179__gbinding_transform_func, block46_data_ref (_data46_), (GClosureNotify) block46_data_unref)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	_tmp46_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
	_tmp47_ = _tmp46_;
	g_object_bind_property_with_closures ((GObject*) _tmp47_, "notify-setting", (GObject*) _data46_->view_model, "notification-is-default", G_BINDING_SYNC_CREATE, (GClosure*) ((___lambda180__gbinding_transform_func == NULL) ? NULL : g_cclosure_new ((GCallback) ___lambda180__gbinding_transform_func, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	_tmp48_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
	_tmp49_ = _tmp48_;
	g_object_bind_property_with_closures ((GObject*) _tmp49_, "pinned", (GObject*) _data46_->view_model, "pinned", G_BINDING_SYNC_CREATE, (GClosure*) ((___lambda181__gbinding_transform_func == NULL) ? NULL : g_cclosure_new ((GCallback) ___lambda181__gbinding_transform_func, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	_tmp50_ = dino_ui_model_conversation_details_get_conversation (_data46_->model);
	_tmp51_ = _tmp50_;
	g_object_bind_property_with_closures ((GObject*) _tmp51_, "type-", (GObject*) _data46_->view_model, "notification-options", G_BINDING_SYNC_CREATE, (GClosure*) ((___lambda182__gbinding_transform_func == NULL) ? NULL : g_cclosure_new ((GCallback) ___lambda182__gbinding_transform_func, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	g_object_bind_property_with_closures ((GObject*) _data46_->model, "data-form", (GObject*) _data46_->view_model, "room-configuration-rows", G_BINDING_SYNC_CREATE, (GClosure*) ((___lambda183__gbinding_transform_func == NULL) ? NULL : g_cclosure_new ((GCallback) ___lambda183__gbinding_transform_func, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	g_signal_connect_data (_data46_->view_model, "pin-changed", (GCallback) ___lambda185__dino_ui_view_model_conversation_details_pin_changed, block46_data_ref (_data46_), (GClosureNotify) block46_data_unref, 0);
	g_signal_connect_data (_data46_->view_model, "block-changed", (GCallback) ___lambda186__dino_ui_view_model_conversation_details_block_changed, block46_data_ref (_data46_), (GClosureNotify) block46_data_unref, 0);
	g_signal_connect_data (_data46_->view_model, "notification-changed", (GCallback) ___lambda187__dino_ui_view_model_conversation_details_notification_changed, block46_data_ref (_data46_), (GClosureNotify) block46_data_unref, 0);
	g_signal_connect_data (_data46_->view_model, "notification-flipped", (GCallback) ___lambda188__dino_ui_view_model_conversation_details_notification_flipped, block46_data_ref (_data46_), (GClosureNotify) block46_data_unref, 0);
	_g_free0 (_tmp24_);
	block46_data_unref (_data46_);
	_data46_ = NULL;
}

static Block47Data*
block47_data_ref (Block47Data* _data47_)
{
	g_atomic_int_inc (&_data47_->_ref_count_);
	return _data47_;
}

static void
block47_data_unref (void * _userdata_)
{
	Block47Data* _data47_;
	_data47_ = (Block47Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data47_->_ref_count_)) {
		_g_object_unref0 (_data47_->model);
		_g_object_unref0 (_data47_->dialog);
		_g_object_unref0 (_data47_->conversation);
		_g_object_unref0 (_data47_->stream_interactor);
		g_slice_free (Block47Data, _data47_);
	}
}

static Block48Data*
block48_data_ref (Block48Data* _data48_)
{
	g_atomic_int_inc (&_data48_->_ref_count_);
	return _data48_;
}

static void
block48_data_unref (void * _userdata_)
{
	Block48Data* _data48_;
	_data48_ = (Block48Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data48_->_ref_count_)) {
		_g_object_unref0 (_data48_->about_row);
		block47_data_unref (_data48_->_data47_);
		_data48_->_data47_ = NULL;
		g_slice_free (Block48Data, _data48_);
	}
}

static void
___lambda189_ (Block48Data* _data48_)
{
	Block47Data* _data47_;
	DinoUiViewModelPreferencesRowEntry* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gboolean _tmp5_;
	_data47_ = _data48_->_data47_;
	_tmp0_ = _data48_->about_row;
	_tmp1_ = dino_ui_view_model_preferences_row_entry_get_text (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = dino_ui_util_get_conversation_display_name (_data47_->stream_interactor, _data47_->conversation);
	_tmp4_ = _tmp3_;
	_tmp5_ = g_strcmp0 (_tmp2_, _tmp4_) != 0;
	_g_free0 (_tmp4_);
	if (_tmp5_) {
		DinoModuleIdentity* _tmp6_;
		gpointer _tmp7_;
		DinoRosterManager* _tmp8_;
		DinoEntitiesAccount* _tmp9_;
		DinoEntitiesAccount* _tmp10_;
		XmppJid* _tmp11_;
		XmppJid* _tmp12_;
		DinoUiViewModelPreferencesRowEntry* _tmp13_;
		const gchar* _tmp14_;
		const gchar* _tmp15_;
		_tmp6_ = dino_roster_manager_IDENTITY;
		_tmp7_ = dino_stream_interactor_get_module (_data47_->stream_interactor, DINO_TYPE_ROSTER_MANAGER, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _tmp6_);
		_tmp8_ = (DinoRosterManager*) _tmp7_;
		_tmp9_ = dino_entities_conversation_get_account (_data47_->conversation);
		_tmp10_ = _tmp9_;
		_tmp11_ = dino_entities_conversation_get_counterpart (_data47_->conversation);
		_tmp12_ = _tmp11_;
		_tmp13_ = _data48_->about_row;
		_tmp14_ = dino_ui_view_model_preferences_row_entry_get_text (_tmp13_);
		_tmp15_ = _tmp14_;
		dino_roster_manager_set_jid_handle (_tmp8_, _tmp10_, _tmp12_, _tmp15_);
		_g_object_unref0 (_tmp8_);
	}
}

static void
____lambda189__dino_ui_view_model_preferences_row_entry_changed (DinoUiViewModelPreferencesRowEntry* _sender,
                                                                 gpointer self)
{
	___lambda189_ (self);
}

static gboolean
__lambda190_ (Block47Data* _data47_)
{
	gboolean _tmp0_ = FALSE;
	DinoUiModelConversationDetails* _tmp1_;
	const gchar* _tmp2_;
	gboolean result;
	_tmp1_ = _data47_->model;
	_tmp2_ = _tmp1_->data_form_bak;
	if (_tmp2_ != NULL) {
		DinoUiModelConversationDetails* _tmp3_;
		const gchar* _tmp4_;
		DinoUiModelConversationDetails* _tmp5_;
		XmppXepDataFormsDataForm* _tmp6_;
		XmppXepDataFormsDataForm* _tmp7_;
		XmppStanzaNode* _tmp8_;
		XmppStanzaNode* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		_tmp3_ = _data47_->model;
		_tmp4_ = _tmp3_->data_form_bak;
		_tmp5_ = _data47_->model;
		_tmp6_ = dino_ui_model_conversation_details_get_data_form (_tmp5_);
		_tmp7_ = _tmp6_;
		_tmp8_ = xmpp_xep_data_forms_data_form_get_stanza_node (_tmp7_);
		_tmp9_ = _tmp8_;
		_tmp10_ = xmpp_stanza_entry_to_string ((XmppStanzaEntry*) _tmp9_, 0);
		_tmp11_ = _tmp10_;
		_tmp0_ = g_strcmp0 (_tmp4_, _tmp11_) != 0;
		_g_free0 (_tmp11_);
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		DinoModuleIdentity* _tmp12_;
		gpointer _tmp13_;
		DinoMucManager* _tmp14_;
		DinoEntitiesAccount* _tmp15_;
		DinoEntitiesAccount* _tmp16_;
		XmppJid* _tmp17_;
		XmppJid* _tmp18_;
		DinoUiModelConversationDetails* _tmp19_;
		XmppXepDataFormsDataForm* _tmp20_;
		XmppXepDataFormsDataForm* _tmp21_;
		_tmp12_ = dino_muc_manager_IDENTITY;
		_tmp13_ = dino_stream_interactor_get_module (_data47_->stream_interactor, DINO_TYPE_MUC_MANAGER, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _tmp12_);
		_tmp14_ = (DinoMucManager*) _tmp13_;
		_tmp15_ = dino_entities_conversation_get_account (_data47_->conversation);
		_tmp16_ = _tmp15_;
		_tmp17_ = dino_entities_conversation_get_counterpart (_data47_->conversation);
		_tmp18_ = _tmp17_;
		_tmp19_ = _data47_->model;
		_tmp20_ = dino_ui_model_conversation_details_get_data_form (_tmp19_);
		_tmp21_ = _tmp20_;
		dino_muc_manager_set_config_form (_tmp14_, _tmp16_, _tmp18_, _tmp21_, NULL, NULL);
		_g_object_unref0 (_tmp14_);
	}
	result = FALSE;
	return result;
}

static gboolean
___lambda190__gtk_window_close_request (GtkWindow* _sender,
                                        gpointer self)
{
	gboolean result;
	result = __lambda190_ (self);
	return result;
}

static void
__lambda191_ (Block47Data* _data47_,
              const gchar* c,
              const gchar* l,
              const gchar* d,
              GObject* wo)
{
	DinoUiConversationDetailsDialog* _tmp0_;
	g_return_if_fail (c != NULL);
	g_return_if_fail (l != NULL);
	g_return_if_fail (wo != NULL);
	_tmp0_ = _data47_->dialog;
	dino_ui_conversation_details_add_entry (c, l, d, wo, _tmp0_);
}

static void
___lambda191__dino_plugins_contact_details_add (DinoPluginsContactDetails* _sender,
                                                const gchar* category,
                                                const gchar* label,
                                                const gchar* desc,
                                                GObject* widget,
                                                gpointer self)
{
	__lambda191_ (self, category, label, desc, widget);
}

DinoUiConversationDetailsDialog*
dino_ui_conversation_details_setup_dialog (DinoEntitiesConversation* conversation,
                                           DinoStreamInteractor* stream_interactor,
                                           GtkWindow* parent)
{
	Block47Data* _data47_;
	DinoEntitiesConversation* _tmp0_;
	DinoStreamInteractor* _tmp1_;
	GtkWindow* _tmp2_;
	DinoUiConversationDetailsDialog* _tmp3_ = NULL;
	DinoUiModelConversationDetails* _tmp4_;
	DinoUiModelConversationDetails* _tmp5_;
	DinoUiModelConversationDetails* _tmp6_;
	DinoUiConversationDetailsDialog* _tmp7_;
	DinoUiViewModelConversationDetails* _tmp8_;
	DinoUiViewModelConversationDetails* _tmp9_;
	DinoUiConversationDetailsDialog* _tmp10_;
	DinoUiViewModelConversationDetails* _tmp11_;
	DinoUiViewModelConversationDetails* _tmp12_;
	GListStore* _tmp13_;
	const gchar* _tmp14_;
	gchar* _tmp15_;
	XmppJid* _tmp16_;
	XmppJid* _tmp17_;
	gchar* _tmp18_;
	DinoUiViewModelPreferencesRowText* _tmp19_ = NULL;
	DinoUiViewModelPreferencesRowText* _tmp20_;
	DinoUiModelConversationDetails* _tmp21_;
	DinoEntitiesConversation* _tmp22_;
	DinoEntitiesConversation* _tmp23_;
	DinoEntitiesConversationType _tmp24_;
	DinoEntitiesConversationType _tmp25_;
	DinoUiModelConversationDetails* _tmp41_;
	DinoEntitiesConversation* _tmp42_;
	DinoEntitiesConversation* _tmp43_;
	DinoEntitiesConversationType _tmp44_;
	DinoEntitiesConversationType _tmp45_;
	DinoUiConversationDetailsDialog* _tmp68_;
	DinoPluginsContactDetails* contact_details = NULL;
	DinoPluginsContactDetails* _tmp69_;
	DinoPluginsContactDetails* _tmp70_;
	DinoUiApplication* app = NULL;
	GApplication* _tmp71_;
	DinoUiApplication* _tmp72_;
	DinoUiApplication* _tmp73_;
	DinoPluginsRegistry* _tmp74_;
	DinoPluginsRegistry* _tmp75_;
	DinoUiContactDetailsSettingsProvider* _tmp76_;
	DinoUiContactDetailsSettingsProvider* _tmp77_;
	DinoUiApplication* _tmp78_;
	DinoPluginsRegistry* _tmp79_;
	DinoPluginsRegistry* _tmp80_;
	DinoUiContactDetailsPermissionsProvider* _tmp81_;
	DinoUiContactDetailsPermissionsProvider* _tmp82_;
	DinoUiConversationDetailsDialog* _tmp103_;
	DinoUiConversationDetailsDialog* _tmp104_;
	DinoUiConversationDetailsDialog* result;
	g_return_val_if_fail (conversation != NULL, NULL);
	g_return_val_if_fail (stream_interactor != NULL, NULL);
	g_return_val_if_fail (parent != NULL, NULL);
	_data47_ = g_slice_new0 (Block47Data);
	_data47_->_ref_count_ = 1;
	_tmp0_ = _g_object_ref0 (conversation);
	_g_object_unref0 (_data47_->conversation);
	_data47_->conversation = _tmp0_;
	_tmp1_ = _g_object_ref0 (stream_interactor);
	_g_object_unref0 (_data47_->stream_interactor);
	_data47_->stream_interactor = _tmp1_;
	_tmp2_ = _g_object_ref0 (parent);
	_tmp3_ = dino_ui_conversation_details_dialog_new ();
	gtk_window_set_transient_for ((GtkWindow*) _tmp3_, _tmp2_);
	_g_object_unref0 (_tmp2_);
	g_object_ref_sink (_tmp3_);
	_data47_->dialog = _tmp3_;
	_tmp4_ = dino_ui_model_conversation_details_new ();
	_data47_->model = _tmp4_;
	_tmp5_ = _data47_->model;
	dino_ui_model_conversation_details_populate (_tmp5_, _data47_->stream_interactor, _data47_->conversation);
	_tmp6_ = _data47_->model;
	_tmp7_ = _data47_->dialog;
	_tmp8_ = dino_ui_conversation_details_dialog_get_model (_tmp7_);
	_tmp9_ = _tmp8_;
	dino_ui_conversation_details_bind_dialog (_tmp6_, _tmp9_, _data47_->stream_interactor);
	_tmp10_ = _data47_->dialog;
	_tmp11_ = dino_ui_conversation_details_dialog_get_model (_tmp10_);
	_tmp12_ = _tmp11_;
	_tmp13_ = _tmp12_->about_rows;
	_tmp14_ = dino_gettext ("XMPP Address");
	_tmp15_ = g_strdup (_tmp14_);
	_tmp16_ = dino_entities_conversation_get_counterpart (_data47_->conversation);
	_tmp17_ = _tmp16_;
	_tmp18_ = xmpp_jid_to_string (_tmp17_);
	_tmp19_ = dino_ui_view_model_preferences_row_text_new ();
	dino_ui_view_model_preferences_row_any_set_title ((DinoUiViewModelPreferencesRowAny*) _tmp19_, _tmp15_);
	_g_free0 (_tmp15_);
	dino_ui_view_model_preferences_row_text_set_text (_tmp19_, _tmp18_);
	_g_free0 (_tmp18_);
	_tmp20_ = _tmp19_;
	g_list_store_append (_tmp13_, (GObject*) _tmp20_);
	_g_object_unref0 (_tmp20_);
	_tmp21_ = _data47_->model;
	_tmp22_ = dino_ui_model_conversation_details_get_conversation (_tmp21_);
	_tmp23_ = _tmp22_;
	_tmp24_ = dino_entities_conversation_get_type_ (_tmp23_);
	_tmp25_ = _tmp24_;
	if (_tmp25_ == DINO_ENTITIES_CONVERSATION_TYPE_CHAT) {
		Block48Data* _data48_;
		const gchar* _tmp26_;
		gchar* _tmp27_;
		DinoUiConversationDetailsDialog* _tmp28_;
		DinoUiViewModelConversationDetails* _tmp29_;
		DinoUiViewModelConversationDetails* _tmp30_;
		const gchar* _tmp31_;
		const gchar* _tmp32_;
		gchar* _tmp33_;
		DinoUiViewModelPreferencesRowEntry* _tmp34_ = NULL;
		DinoUiViewModelPreferencesRowEntry* _tmp35_;
		DinoUiConversationDetailsDialog* _tmp36_;
		DinoUiViewModelConversationDetails* _tmp37_;
		DinoUiViewModelConversationDetails* _tmp38_;
		GListStore* _tmp39_;
		DinoUiViewModelPreferencesRowEntry* _tmp40_;
		_data48_ = g_slice_new0 (Block48Data);
		_data48_->_ref_count_ = 1;
		_data48_->_data47_ = block47_data_ref (_data47_);
		_tmp26_ = dino_gettext ("Display name");
		_tmp27_ = g_strdup (_tmp26_);
		_tmp28_ = _data47_->dialog;
		_tmp29_ = dino_ui_conversation_details_dialog_get_model (_tmp28_);
		_tmp30_ = _tmp29_;
		_tmp31_ = dino_ui_view_model_conversation_details_get_name (_tmp30_);
		_tmp32_ = _tmp31_;
		_tmp33_ = g_strdup (_tmp32_);
		_tmp34_ = dino_ui_view_model_preferences_row_entry_new ();
		dino_ui_view_model_preferences_row_any_set_title ((DinoUiViewModelPreferencesRowAny*) _tmp34_, _tmp27_);
		_g_free0 (_tmp27_);
		dino_ui_view_model_preferences_row_entry_set_text (_tmp34_, _tmp33_);
		_g_free0 (_tmp33_);
		_data48_->about_row = _tmp34_;
		_tmp35_ = _data48_->about_row;
		g_signal_connect_data (_tmp35_, "changed", (GCallback) ____lambda189__dino_ui_view_model_preferences_row_entry_changed, block48_data_ref (_data48_), (GClosureNotify) block48_data_unref, 0);
		_tmp36_ = _data47_->dialog;
		_tmp37_ = dino_ui_conversation_details_dialog_get_model (_tmp36_);
		_tmp38_ = _tmp37_;
		_tmp39_ = _tmp38_->about_rows;
		_tmp40_ = _data48_->about_row;
		g_list_store_append (_tmp39_, (GObject*) _tmp40_);
		block48_data_unref (_data48_);
		_data48_ = NULL;
	}
	_tmp41_ = _data47_->model;
	_tmp42_ = dino_ui_model_conversation_details_get_conversation (_tmp41_);
	_tmp43_ = _tmp42_;
	_tmp44_ = dino_entities_conversation_get_type_ (_tmp43_);
	_tmp45_ = _tmp44_;
	if (_tmp45_ == DINO_ENTITIES_CONVERSATION_TYPE_GROUPCHAT) {
		gchar* topic = NULL;
		DinoModuleIdentity* _tmp46_;
		gpointer _tmp47_;
		DinoMucManager* _tmp48_;
		XmppJid* _tmp49_;
		XmppJid* _tmp50_;
		DinoEntitiesAccount* _tmp51_;
		DinoEntitiesAccount* _tmp52_;
		gchar* _tmp53_;
		gchar* _tmp54_;
		gboolean _tmp55_ = FALSE;
		const gchar* _tmp56_;
		_tmp46_ = dino_muc_manager_IDENTITY;
		_tmp47_ = dino_stream_interactor_get_module (_data47_->stream_interactor, DINO_TYPE_MUC_MANAGER, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _tmp46_);
		_tmp48_ = (DinoMucManager*) _tmp47_;
		_tmp49_ = dino_entities_conversation_get_counterpart (_data47_->conversation);
		_tmp50_ = _tmp49_;
		_tmp51_ = dino_entities_conversation_get_account (_data47_->conversation);
		_tmp52_ = _tmp51_;
		_tmp53_ = dino_muc_manager_get_groupchat_subject (_tmp48_, _tmp50_, _tmp52_);
		_tmp54_ = _tmp53_;
		_g_object_unref0 (_tmp48_);
		topic = _tmp54_;
		_tmp56_ = topic;
		if (_tmp56_ != NULL) {
			const gchar* _tmp57_;
			_tmp57_ = topic;
			_tmp55_ = g_strcmp0 (_tmp57_, "") != 0;
		} else {
			_tmp55_ = FALSE;
		}
		if (_tmp55_) {
			DinoUiConversationDetailsDialog* _tmp58_;
			DinoUiViewModelConversationDetails* _tmp59_;
			DinoUiViewModelConversationDetails* _tmp60_;
			GListStore* _tmp61_;
			const gchar* _tmp62_;
			gchar* _tmp63_;
			const gchar* _tmp64_;
			gchar* _tmp65_;
			DinoUiViewModelPreferencesRowText* _tmp66_ = NULL;
			DinoUiViewModelPreferencesRowText* _tmp67_;
			_tmp58_ = _data47_->dialog;
			_tmp59_ = dino_ui_conversation_details_dialog_get_model (_tmp58_);
			_tmp60_ = _tmp59_;
			_tmp61_ = _tmp60_->about_rows;
			_tmp62_ = dino_gettext ("Topic");
			_tmp63_ = g_strdup (_tmp62_);
			_tmp64_ = topic;
			_tmp65_ = dino_ui_util_parse_add_markup (_tmp64_, NULL, TRUE, TRUE);
			_tmp66_ = dino_ui_view_model_preferences_row_text_new ();
			dino_ui_view_model_preferences_row_any_set_title ((DinoUiViewModelPreferencesRowAny*) _tmp66_, _tmp63_);
			_g_free0 (_tmp63_);
			dino_ui_view_model_preferences_row_text_set_text (_tmp66_, _tmp65_);
			_g_free0 (_tmp65_);
			_tmp67_ = _tmp66_;
			g_list_store_append (_tmp61_, (GObject*) _tmp67_);
			_g_object_unref0 (_tmp67_);
		}
		_g_free0 (topic);
	}
	_tmp68_ = _data47_->dialog;
	g_signal_connect_data ((GtkWindow*) _tmp68_, "close-request", (GCallback) ___lambda190__gtk_window_close_request, block47_data_ref (_data47_), (GClosureNotify) block47_data_unref, 0);
	_tmp69_ = dino_plugins_contact_details_new ();
	contact_details = _tmp69_;
	_tmp70_ = contact_details;
	g_signal_connect_data (_tmp70_, "add", (GCallback) ___lambda191__dino_plugins_contact_details_add, block47_data_ref (_data47_), (GClosureNotify) block47_data_unref, 0);
	_tmp71_ = g_application_get_default ();
	_tmp72_ = _g_object_ref0 (DINO_UI_IS_APPLICATION (_tmp71_) ? ((DinoUiApplication*) _tmp71_) : NULL);
	app = _tmp72_;
	_tmp73_ = app;
	_tmp74_ = dino_application_get_plugin_registry ((DinoApplication*) _tmp73_);
	_tmp75_ = _tmp74_;
	_tmp76_ = dino_ui_contact_details_settings_provider_new (_data47_->stream_interactor);
	_tmp77_ = _tmp76_;
	dino_plugins_registry_register_contact_details_entry (_tmp75_, (DinoPluginsContactDetailsProvider*) _tmp77_);
	_g_object_unref0 (_tmp77_);
	_tmp78_ = app;
	_tmp79_ = dino_application_get_plugin_registry ((DinoApplication*) _tmp78_);
	_tmp80_ = _tmp79_;
	_tmp81_ = dino_ui_contact_details_permissions_provider_new (_data47_->stream_interactor);
	_tmp82_ = _tmp81_;
	dino_plugins_registry_register_contact_details_entry (_tmp80_, (DinoPluginsContactDetailsProvider*) _tmp82_);
	_g_object_unref0 (_tmp82_);
	{
		GeeArrayList* _provider_list = NULL;
		DinoUiApplication* _tmp83_;
		DinoPluginsRegistry* _tmp84_;
		DinoPluginsRegistry* _tmp85_;
		GeeArrayList* _tmp86_;
		gint _provider_size = 0;
		GeeArrayList* _tmp87_;
		gint _tmp88_;
		gint _tmp89_;
		gint _provider_index = 0;
		_tmp83_ = app;
		_tmp84_ = dino_application_get_plugin_registry ((DinoApplication*) _tmp83_);
		_tmp85_ = _tmp84_;
		_tmp86_ = _tmp85_->contact_details_entries;
		_provider_list = _tmp86_;
		_tmp87_ = _provider_list;
		_tmp88_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp87_);
		_tmp89_ = _tmp88_;
		_provider_size = _tmp89_;
		_provider_index = -1;
		while (TRUE) {
			gint _tmp90_;
			gint _tmp91_;
			DinoPluginsContactDetailsProvider* provider = NULL;
			GeeArrayList* _tmp92_;
			gpointer _tmp93_;
			AdwPreferencesGroup* preferences_group = NULL;
			DinoPluginsContactDetailsProvider* _tmp94_;
			GObject* _tmp95_;
			AdwPreferencesGroup* _tmp96_;
			DinoPluginsContactDetailsProvider* _tmp101_;
			DinoPluginsContactDetails* _tmp102_;
			_provider_index = _provider_index + 1;
			_tmp90_ = _provider_index;
			_tmp91_ = _provider_size;
			if (!(_tmp90_ < _tmp91_)) {
				break;
			}
			_tmp92_ = _provider_list;
			_tmp93_ = gee_abstract_list_get ((GeeAbstractList*) _tmp92_, _provider_index);
			provider = (DinoPluginsContactDetailsProvider*) _tmp93_;
			_tmp94_ = provider;
			_tmp95_ = dino_plugins_contact_details_provider_get_widget (_tmp94_, _data47_->conversation);
			preferences_group = G_TYPE_CHECK_INSTANCE_CAST (_tmp95_, adw_preferences_group_get_type (), AdwPreferencesGroup);
			_tmp96_ = preferences_group;
			if (_tmp96_ != NULL) {
				DinoUiConversationDetailsDialog* _tmp97_;
				DinoPluginsContactDetailsProvider* _tmp98_;
				GObject* _tmp99_;
				AdwPreferencesGroup* _tmp100_;
				_tmp97_ = _data47_->dialog;
				_tmp98_ = provider;
				_tmp99_ = dino_plugins_contact_details_provider_get_widget (_tmp98_, _data47_->conversation);
				_tmp100_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp99_, adw_preferences_group_get_type (), AdwPreferencesGroup);
				dino_ui_conversation_details_dialog_add_encryption_tab_element (_tmp97_, _tmp100_);
				_g_object_unref0 (_tmp100_);
			}
			_tmp101_ = provider;
			_tmp102_ = contact_details;
			dino_plugins_contact_details_provider_populate (_tmp101_, _data47_->conversation, _tmp102_, DINO_PLUGINS_WIDGET_TYPE_GTK4);
			_g_object_unref0 (preferences_group);
			_g_object_unref0 (provider);
		}
	}
	_tmp103_ = _data47_->dialog;
	_tmp104_ = _g_object_ref0 (_tmp103_);
	result = _tmp104_;
	_g_object_unref0 (app);
	_g_object_unref0 (contact_details);
	block47_data_unref (_data47_);
	_data47_ = NULL;
	return result;
}

void
dino_ui_conversation_details_add_entry (const gchar* category,
                                        const gchar* label,
                                        const gchar* description,
                                        GObject* wo,
                                        DinoUiConversationDetailsDialog* dialog)
{
	GtkWidget* widget = NULL;
	GtkWidget* _tmp0_;
	GtkWidget* _tmp1_;
	DinoUiViewModelPreferencesRowWidgetDeprecated* view_model = NULL;
	gchar* _tmp11_;
	GtkWidget* _tmp12_;
	GtkWidget* _tmp13_;
	DinoUiViewModelPreferencesRowWidgetDeprecated* _tmp14_ = NULL;
	const gchar* _tmp15_;
	GQuark _tmp17_ = 0U;
	static GQuark _tmp16_label0 = 0;
	static GQuark _tmp16_label1 = 0;
	static GQuark _tmp16_label2 = 0;
	g_return_if_fail (category != NULL);
	g_return_if_fail (label != NULL);
	g_return_if_fail (wo != NULL);
	g_return_if_fail (dialog != NULL);
	if (!G_TYPE_CHECK_INSTANCE_TYPE (wo, gtk_widget_get_type ())) {
		return;
	}
	_tmp0_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (wo, gtk_widget_get_type (), GtkWidget));
	widget = _tmp0_;
	_tmp1_ = widget;
	if (g_type_is_a (G_TYPE_FROM_INSTANCE ((GObject*) _tmp1_), gtk_entry_get_type ())) {
		DinoUiUtilEntryLabelHybrid* hybrid = NULL;
		GtkWidget* _tmp2_;
		DinoUiUtilEntryLabelHybrid* _tmp3_ = NULL;
		DinoUiUtilEntryLabelHybrid* _tmp4_;
		GtkWidget* _tmp5_;
		_tmp2_ = widget;
		_tmp3_ = dino_ui_util_entry_label_hybrid_new_wrap (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp2_) : NULL);
		dino_ui_util_entry_label_hybrid_set_xalign (_tmp3_, (gfloat) 1);
		g_object_ref_sink (_tmp3_);
		hybrid = _tmp3_;
		_tmp4_ = hybrid;
		_tmp5_ = _g_object_ref0 ((GtkWidget*) _tmp4_);
		_g_object_unref0 (widget);
		widget = _tmp5_;
		_g_object_unref0 (hybrid);
	} else {
		GtkWidget* _tmp6_;
		_tmp6_ = widget;
		if (g_type_is_a (G_TYPE_FROM_INSTANCE ((GObject*) _tmp6_), gtk_combo_box_text_get_type ())) {
			DinoUiUtilComboBoxTextLabelHybrid* hybrid = NULL;
			GtkWidget* _tmp7_;
			DinoUiUtilComboBoxTextLabelHybrid* _tmp8_ = NULL;
			DinoUiUtilComboBoxTextLabelHybrid* _tmp9_;
			GtkWidget* _tmp10_;
			_tmp7_ = widget;
			_tmp8_ = dino_ui_util_combo_box_text_label_hybrid_new_wrap (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, gtk_combo_box_text_get_type ()) ? ((GtkComboBoxText*) _tmp7_) : NULL);
			dino_ui_util_combo_box_text_label_hybrid_set_xalign (_tmp8_, (gfloat) 1);
			g_object_ref_sink (_tmp8_);
			hybrid = _tmp8_;
			_tmp9_ = hybrid;
			_tmp10_ = _g_object_ref0 ((GtkWidget*) _tmp9_);
			_g_object_unref0 (widget);
			widget = _tmp10_;
			_g_object_unref0 (hybrid);
		}
	}
	_tmp11_ = g_strdup (label);
	_tmp12_ = widget;
	_tmp13_ = _g_object_ref0 (_tmp12_);
	_tmp14_ = dino_ui_view_model_preferences_row_widget_deprecated_new ();
	dino_ui_view_model_preferences_row_any_set_title ((DinoUiViewModelPreferencesRowAny*) _tmp14_, _tmp11_);
	_g_free0 (_tmp11_);
	_g_object_unref0 (_tmp14_->widget);
	_tmp14_->widget = _tmp13_;
	view_model = _tmp14_;
	_tmp15_ = category;
	_tmp17_ = (NULL == _tmp15_) ? 0 : g_quark_from_string (_tmp15_);
	if (((_tmp17_ == ((0 != _tmp16_label0) ? _tmp16_label0 : (_tmp16_label0 = g_quark_from_static_string ("Permissions")))) || (_tmp17_ == ((0 != _tmp16_label1) ? _tmp16_label1 : (_tmp16_label1 = g_quark_from_static_string ("Local Settings"))))) || (_tmp17_ == ((0 != _tmp16_label2) ? _tmp16_label2 : (_tmp16_label2 = g_quark_from_static_string ("Settings"))))) {
		switch (0) {
			default:
			{
				DinoUiViewModelConversationDetails* _tmp18_;
				DinoUiViewModelConversationDetails* _tmp19_;
				GListStore* _tmp20_;
				DinoUiViewModelPreferencesRowWidgetDeprecated* _tmp21_;
				_tmp18_ = dino_ui_conversation_details_dialog_get_model (dialog);
				_tmp19_ = _tmp18_;
				_tmp20_ = _tmp19_->settings_rows;
				_tmp21_ = view_model;
				g_list_store_append (_tmp20_, (GObject*) _tmp21_);
				break;
			}
		}
	} else {
		switch (0) {
			default:
			{
				break;
			}
		}
	}
	_g_object_unref0 (view_model);
	_g_object_unref0 (widget);
}

static inline gpointer
_vala_memdup2 (gconstpointer mem,
               gsize byte_size)
{
	gpointer new_mem;
	if (mem && byte_size != 0) {
		new_mem = g_malloc (byte_size);
		memcpy (new_mem, mem, byte_size);
	} else {
		new_mem = NULL;
	}
	return new_mem;
}

